Test Report

# Summary

Started | 2025-06-06 14:35:41
Ended | 2025-06-06 14:44:42
Duration | 0:09:00.730067
Total run time | 0:08:45.214806

100 passed 5 skipped

# Warnings

## Warnings 189

- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:98
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:102
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:73
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:67
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:115
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:107
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- DeprecationWarning 'pkgutil.get_loader' is deprecated and slated for removal in Python 3.14; use importlib.util.find_spec() instead
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/acwater/polymer_enmap.py:53
- DeprecationWarning 'pkgutil.get_loader' is deprecated and slated for removal in Python 3.14; use importlib.util.find_spec() instead
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/acwater/level1_enmap.py:67
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Automatic nodata value detection returned the value 0.0 for GeoArray 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER' but this seems to be unreliable (occurs in only 2 image corners). To avoid automatic detection, just pass the correct nodata value.
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/geoarray/baseclasses.py:806
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=169) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66

# Tests

## tests/test_cli_parser.py 7 0:00:00.734477

### PASSED Test_CLIParser::test_json_opts 0:00:00.194221

Started | 2025-06-06 14:35:54
Ended | 2025-06-06 14:35:54
Duration | 0:00:00.194221
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_output_nodata_value 0:00:00.121586

Started | 2025-06-06 14:35:54
Ended | 2025-06-06 14:35:54
Duration | 0:00:00.121586
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_acceptance 0:00:00.080751

Started | 2025-06-06 14:35:54
Ended | 2025-06-06 14:35:54
Duration | 0:00:00.080751
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_boolean 0:00:00.129347

Started | 2025-06-06 14:35:54
Ended | 2025-06-06 14:35:54
Duration | 0:00:00.129347
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_list 0:00:00.046540

Started | 2025-06-06 14:35:54
Ended | 2025-06-06 14:35:54
Duration | 0:00:00.046540
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_tgtepsg 0:00:00.080486

Started | 2025-06-06 14:35:54
Ended | 2025-06-06 14:35:54
Duration | 0:00:00.080486
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_tgtprj 0:00:00.081546

Started | 2025-06-06 14:35:54
Ended | 2025-06-06 14:35:54
Duration | 0:00:00.081546
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_config.py 13 0:00:00.355406

### PASSED Test_get_options::test_target_is_file_no_validation 0:00:00.009042

Started | 2025-06-06 14:35:54
Ended | 2025-06-06 14:35:54
Duration | 0:00:00.009042
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_get_options::test_target_is_file_validation 0:00:00.017299

Started | 2025-06-06 14:35:54
Ended | 2025-06-06 14:35:54
Duration | 0:00:00.017299
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_invalid_filepath 0:00:00.036127

Started | 2025-06-06 14:35:54
Ended | 2025-06-06 14:35:54
Duration | 0:00:00.036127
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_file 0:00:00.043247

Started | 2025-06-06 14:35:54
Ended | 2025-06-06 14:35:55
Duration | 0:00:00.043247
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_param_acceptance 0:00:00.033566

Started | 2025-06-06 14:35:55
Ended | 2025-06-06 14:35:55
Duration | 0:00:00.033566
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_allfine 0:00:00.033301

Started | 2025-06-06 14:35:55
Ended | 2025-06-06 14:35:55
Duration | 0:00:00.033301
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_badcomment 0:00:00.016242

Started | 2025-06-06 14:35:55
Ended | 2025-06-06 14:35:55
Duration | 0:00:00.016242
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_nojson 0:00:00.015985

Started | 2025-06-06 14:35:55
Ended | 2025-06-06 14:35:55
Duration | 0:00:00.015985
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_schema_violation 0:00:00.024450

Started | 2025-06-06 14:35:55
Ended | 2025-06-06 14:35:55
Duration | 0:00:00.024450
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_undecodable_val 0:00:00.016133

Started | 2025-06-06 14:35:55
Ended | 2025-06-06 14:35:55
Duration | 0:00:00.016133
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_plain_args 0:00:00.033030

Started | 2025-06-06 14:35:55
Ended | 2025-06-06 14:35:55
Duration | 0:00:00.033030
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_to_dict_validity 0:00:00.042427

Started | 2025-06-06 14:35:55
Ended | 2025-06-06 14:35:55
Duration | 0:00:00.042427
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_to_jsonable_dict 0:00:00.034555

Started | 2025-06-06 14:35:55
Ended | 2025-06-06 14:35:55
Duration | 0:00:00.034555
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_controller.py 5 0:03:03.497402

### PASSED Test_EnPT_Controller::test_run_all_processors 0:00:08.461411

Started | 2025-06-06 14:35:55
Ended | 2025-06-06 14:36:03
Duration | 0:00:08.461411
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': True,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': True,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': 50,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/dem_map_geo.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/AlpineTest1_CWV2_SM0.zip',
                      'path_l1b_enmap_image_gapfill': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/AlpineTest2_CWV2_SM0.zip',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmp88ae58tz'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': False,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'land',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spatial',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': False},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/06 14:35:55:   Reading metadata for VNIR detector...
    2025/06/06 14:35:56:   Calculating solar irradiance...
    2025/06/06 14:35:56:   Reading metadata for SWIR detector...
    2025/06/06 14:35:56:   Calculating solar irradiance...
    2025/06/06 14:35:56:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:35:56:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:35:56:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:35:56:   Reading metadata for VNIR detector...
    2025/06/06 14:35:56:   Calculating solar irradiance...
    2025/06/06 14:35:56:   Reading metadata for SWIR detector...
    2025/06/06 14:35:57:   Calculating solar irradiance...
    2025/06/06 14:35:57:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:35:57:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:35:57:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:35:57:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:35:57:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:35:57:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:35:57:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:35:57:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:35:58:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:35:58:   Skipping atmospheric correction as configured and computing top-of-atmosphere reflectance instead.
    2025/06/06 14:35:58:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/06/06 14:35:59:   Converting TOA radiance to TOA reflectance for SWIR detector...
    2025/06/06 14:35:59:   Starting orthorectification...
    2025/06/06 14:35:59:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32632): (627300.0, 5257740.0, 656040.0, 5266620.0)
    2025/06/06 14:35:59:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:36:00:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:36:01:   Merging VNIR and SWIR data...
    2025/06/06 14:36:01:   Orthorectifying 'mask_clouds' attribute...
    2025/06/06 14:36:01:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/06 14:36:02:   Generating L2A metadata...
    2025/06/06 14:36:03:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (296, 958, 209) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.TIF.
    Writing GeoArray of size (296, 958) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (296, 958, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (296, 958, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:36:03:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_header.xml
    2025/06/06 14:36:03:   L2A product successfully written!
    2025/06/06 14:36:03:   Total runtime of the processing chain: 0:00:08.400965

##### Captured stderr call

    2025/06/06 14:35:57:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/06 14:35:57:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/06 14:35:57:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/06 14:35:57:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/06 14:35:57:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/06 14:36:03:   The 'mask_landwater' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:36:03:   The 'mask_cloudshadow' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:36:03:   The 'mask_haze' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:36:03:   The 'mask_snow' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:36:03:   The 'mask_cirrus' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:36:03:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/06 14:36:03:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:36:03:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:36:03:   No XML metadata conversion implemented for datasets different to the DLR format.Metadata XML file will be empty.

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata::test_run_all_processors 0:00:57.740325

Started | 2025-06-06 14:36:03
Ended | 2025-06-06 14:37:01
Duration | 0:00:57.740325
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 24,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': 50,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-799.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpbzgtld_b'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'land',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spatial',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': False},
                    'geometry': {'enable_absolute_coreg': True,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/T30TXQ_20170218T110111_B05__sub.tif'},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/06 14:36:04:   Reading metadata for VNIR detector...
    2025/06/06 14:36:04:   Calculating solar irradiance...
    2025/06/06 14:36:04:   Reading metadata for SWIR detector...
    2025/06/06 14:36:04:   Calculating solar irradiance...
    2025/06/06 14:36:04:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:36:05:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:36:05:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:36:05:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:36:06:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:36:06:   Computing VNIR geolayer...
    2025/06/06 14:36:06:   Computing SWIR geolayer...
    2025/06/06 14:36:06:   Temporarily transforming EnMAP band 40 to map geometry for co-registration.
    2025/06/06 14:36:07:   Temporarily transforming EnMAP water mask to map geometry for co-registration.
    2025/06/06 14:36:07:   Preparing reference image for co-registration.
    2025/06/06 14:36:07:   Computing tie points between the EnMAP image and the given spatial reference image.
    Calculating footprint polygon and actual data corner coordinates for reference image...
    Bounding box of calculated footprint for reference image:
    	(637005.0, 4940640.0, 666300.0, 4949895.0)
    Bounding box of calculated footprint for image to be shifted:
    	(637009.9236523756, 4940648.633479693, 666298.6703669054, 4949893.375184522)
    Matching window position (X,Y): 651655.4222751356/4945271.096554121
    Target window size (256, 256) not possible due to too small overlap area or window position too close to an image edge. New matching window size: (164, 164).
    Initializing tie points grid...
    With respect to the provided bad data mask(s) 81 points of initially 242 have been excluded.
    Calculating tie point grid (161 points) using 24 CPU cores...
    Found 131 matches.
    Performing validity checks...
    41 tie points flagged by level 1 filtering (reliability).
    63 tie points flagged by level 2 filtering (SSIM).
    4 tie points flagged by level 3 filtering (RANSAC)
    47 valid tie points remain after filtering.
    2025/06/06 14:36:18:   Generating misregistration array.
    interpolation runtime: 0.22s
    interpolation runtime: 0.19s
    2025/06/06 14:36:19:   Transforming spatial optimization results back to sensor geometry.
    2025/06/06 14:36:19:   Applying results of spatial optimization to geolayer.
    2025/06/06 14:36:19:   Pre-processing DEM for VNIR...
    2025/06/06 14:36:19:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/06/06 14:36:19:   Pre-processing DEM for SWIR...
    2025/06/06 14:36:19:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/06/06 14:36:19:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/06/06 14:36:20:   Starting atmospheric correction for VNIR and SWIR detector in 'land' mode. Source radiometric unit code is 'TOARad'.
    2025/06/06 14:36:20:   Running atmospheric correction in 'land' mode, i.e., SICOR is applied to ALL surfaces. Uncertainty is expected for water surfaces because SICOR is designed for land only.
    2025/06/06 14:36:20:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 24,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': False,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/06/06 14:36:20:   Setting up forward operator...
    2025/06/06 14:36:20:   SICOR is applied to land AND water pixels.
    2025/06/06 14:36:20:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/06/06 14:36:22:   Getting observation metadata...
    2025/06/06 14:36:22:   Checking if observation metadata values are within LUT value ranges...
    2025/06/06 14:36:22:   Loading solar irradiance model...
    2025/06/06 14:36:22:   Loading RT LUT...
    2025/06/06 14:36:22:   LUT file was properly downloaded and is available for AC!
    2025/06/06 14:36:22:   Converting LUT to Fontenla solar model...
    2025/06/06 14:36:23:   Resampling LUT to EnMAP wavelengths...
    2025/06/06 14:36:44:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/06/06 14:36:44:   Calculating absorption coefficients of liquid water and ice...
    2025/06/06 14:36:44:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/06/06 14:36:45:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/06/06 14:36:46:   Performing first guess liquid water retrieval based on the NDWI...
    2025/06/06 14:36:46:   Performing first guess ice retrieval based on the NDSI...
    2025/06/06 14:36:46:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/06/06 14:36:46:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/06/06 14:36:46:   Preparing segmented SWIR L1B data cube...
    2025/06/06 14:36:47:   Performing 3 phases of water retrieval...
    2025/06/06 14:36:47:   Setting up multiprocessing...
    2025/06/06 14:36:47:   Multiprocessing on 24 cpu's
    2025/06/06 14:36:47:   Preparing optimal estimation input...
    2025/06/06 14:36:47:   Optimization...
    2025/06/06 14:36:49:   Done!
    2025/06/06 14:36:49:   Runtime: 2.34 s
    2025/06/06 14:36:49:   Smoothing segmented CWV retrieval map...
    2025/06/06 14:36:49:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/06/06 14:36:50:   Starting surface reflectance retrieval...
    2025/06/06 14:36:50:   Calculating surface reflectance for vnir detector...
    2025/06/06 14:36:52:   Calculating surface reflectance for swir detector...
    2025/06/06 14:36:55:   Smoothing segmented liquid water and ice maps...
    2025/06/06 14:36:56:   SICOR atmospheric correction for EnMAP in land mode successfully finished!
    2025/06/06 14:36:56:   Joining results of atmospheric correction.
    2025/06/06 14:36:56:   Starting orthorectification...
    2025/06/06 14:36:56:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636960.0, 4940670.0, 666090.0, 4949310.0)
    2025/06/06 14:36:56:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:36:57:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:36:58:   Merging VNIR and SWIR data...
    2025/06/06 14:36:58:   Orthorectifying 'mask_landwater' attribute...
    2025/06/06 14:36:58:   Orthorectifying 'mask_clouds' attribute...
    2025/06/06 14:36:58:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/06 14:36:58:   Orthorectifying 'mask_haze' attribute...
    2025/06/06 14:36:59:   Orthorectifying 'mask_snow' attribute...
    2025/06/06 14:36:59:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/06 14:36:59:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/06 14:36:59:   Generating L2A metadata...
    2025/06/06 14:37:00:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (288, 971, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (288, 971, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (288, 971, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    2025/06/06 14:37:01:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/06/06 14:37:01:   L2A product successfully written!
    2025/06/06 14:37:01:   Total runtime of the processing chain: 0:00:57.677385

##### Captured stderr call

    2025/06/06 14:36:04:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/06/06 14:36:06:   Statically using band 40 for co-registration.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.1% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.8% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.2% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.0% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.2% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.1% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.3% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.1% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.2% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.2% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.3% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.4% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.1% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.3% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.2% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.1% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.1% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.1% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.2% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.1% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.1% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.4% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 27.1% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 28.0% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 29.0% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 30.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 31.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 32.3% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 33.2% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 34.0% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 35.0% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 36.3% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 37.1% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 38.1% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 39.2% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 40.0% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 41.0% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 42.1% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 43.1% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 44.1% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 45.4% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 46.2% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 47.2% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 48.1% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 49.1% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 50.1% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 51.2% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 52.0% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 53.3% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 54.6% Complete  => 0:00:00
    Warping progress     |============================----------------------| 55.3% Complete  => 0:00:00
    Warping progress     |============================----------------------| 56.2% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.2% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 58.0% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 59.5% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 60.3% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 61.3% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 62.4% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.0% Complete  => 0:00:00
    Warping progress     |================================------------------| 64.2% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 65.6% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.2% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.2% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.0% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.3% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.1% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.2% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.0% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.3% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.1% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.1% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.1% Complete  => 0:00:00
    Warping progress     |============================================------| 87.0% Complete  => 0:00:00
    Warping progress     |============================================------| 88.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.3% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.1% Complete  => 0:00:00
    Warping progress     |================================================--| 96.3% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.2% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.2% Complete  => 0:00:00
    Warping progress     |==================================================| 99.2% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.9% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 2.5% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 3.7% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 4.3% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 5.0% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 5.6% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 6.2% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 6.8% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 7.5% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 8.1% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 8.7% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 9.3% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 9.9% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 10.6% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 11.2% Complete  => 0:00:10
    	progress: |======--------------------------------------------| 11.8% Complete  => 0:00:10
    	progress: |======--------------------------------------------| 12.4% Complete  => 0:00:10
    	progress: |=======-------------------------------------------| 13.0% Complete  => 0:00:10
    	progress: |=======-------------------------------------------| 13.7% Complete  => 0:00:10
    	progress: |=======-------------------------------------------| 14.3% Complete  => 0:00:10
    	progress: |=======-------------------------------------------| 14.9% Complete  => 0:00:10
    	progress: |========------------------------------------------| 15.5% Complete  => 0:00:10
    	progress: |========------------------------------------------| 16.1% Complete  => 0:00:10
    	progress: |========------------------------------------------| 16.8% Complete  => 0:00:10
    	progress: |=========-----------------------------------------| 17.4% Complete  => 0:00:10
    	progress: |=========-----------------------------------------| 18.0% Complete  => 0:00:10
    	progress: |=========-----------------------------------------| 18.6% Complete  => 0:00:10
    	progress: |==========----------------------------------------| 19.3% Complete  => 0:00:10
    	progress: |==========----------------------------------------| 19.9% Complete  => 0:00:10
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 22.4% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 23.0% Complete  => 0:00:10
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:10
    	progress: |============--------------------------------------| 24.2% Complete  => 0:00:10
    	progress: |============--------------------------------------| 24.8% Complete  => 0:00:10
    	progress: |=============-------------------------------------| 25.5% Complete  => 0:00:10
    	progress: |=============-------------------------------------| 26.1% Complete  => 0:00:10
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:10
    	progress: |==============------------------------------------| 27.3% Complete  => 0:00:10
    	progress: |==============------------------------------------| 28.0% Complete  => 0:00:10
    	progress: |==============------------------------------------| 28.6% Complete  => 0:00:10
    	progress: |===============-----------------------------------| 29.2% Complete  => 0:00:10
    	progress: |===============-----------------------------------| 29.8% Complete  => 0:00:10
    	progress: |===============-----------------------------------| 30.4% Complete  => 0:00:10
    	progress: |================----------------------------------| 31.1% Complete  => 0:00:10
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:10
    	progress: |================----------------------------------| 32.3% Complete  => 0:00:10
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:10
    	progress: |=================---------------------------------| 33.5% Complete  => 0:00:10
    	progress: |=================---------------------------------| 34.2% Complete  => 0:00:10
    	progress: |=================---------------------------------| 34.8% Complete  => 0:00:10
    	progress: |==================--------------------------------| 35.4% Complete  => 0:00:10
    	progress: |==================--------------------------------| 36.0% Complete  => 0:00:10
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:10
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:10
    	progress: |===================-------------------------------| 37.9% Complete  => 0:00:10
    	progress: |===================-------------------------------| 38.5% Complete  => 0:00:10
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:10
    	progress: |====================------------------------------| 39.8% Complete  => 0:00:10
    	progress: |====================------------------------------| 40.4% Complete  => 0:00:10
    	progress: |====================------------------------------| 41.0% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 41.6% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 42.9% Complete  => 0:00:10
    	progress: |======================----------------------------| 43.5% Complete  => 0:00:10
    	progress: |======================----------------------------| 44.1% Complete  => 0:00:10
    	progress: |======================----------------------------| 44.7% Complete  => 0:00:10
    	progress: |=======================---------------------------| 45.3% Complete  => 0:00:10
    	progress: |=======================---------------------------| 46.0% Complete  => 0:00:10
    	progress: |=======================---------------------------| 46.6% Complete  => 0:00:10
    	progress: |========================--------------------------| 47.2% Complete  => 0:00:10
    	progress: |========================--------------------------| 47.8% Complete  => 0:00:10
    	progress: |========================--------------------------| 48.4% Complete  => 0:00:10
    	progress: |=========================-------------------------| 49.1% Complete  => 0:00:10
    	progress: |=========================-------------------------| 49.7% Complete  => 0:00:10
    	progress: |=========================-------------------------| 50.3% Complete  => 0:00:10
    	progress: |=========================-------------------------| 50.9% Complete  => 0:00:10
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:10
    	progress: |==========================------------------------| 52.2% Complete  => 0:00:10
    	progress: |==========================------------------------| 52.8% Complete  => 0:00:10
    	progress: |===========================-----------------------| 53.4% Complete  => 0:00:10
    	progress: |===========================-----------------------| 54.0% Complete  => 0:00:10
    	progress: |===========================-----------------------| 54.7% Complete  => 0:00:10
    	progress: |============================----------------------| 55.3% Complete  => 0:00:10
    	progress: |============================----------------------| 55.9% Complete  => 0:00:10
    	progress: |============================----------------------| 56.5% Complete  => 0:00:10
    	progress: |=============================---------------------| 57.1% Complete  => 0:00:10
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:10
    	progress: |=============================---------------------| 58.4% Complete  => 0:00:10
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:10
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:10
    	progress: |==============================--------------------| 60.2% Complete  => 0:00:10
    	progress: |==============================--------------------| 60.9% Complete  => 0:00:10
    	progress: |===============================-------------------| 61.5% Complete  => 0:00:10
    	progress: |===============================-------------------| 62.1% Complete  => 0:00:10
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:10
    	progress: |================================------------------| 63.4% Complete  => 0:00:10
    	progress: |================================------------------| 64.0% Complete  => 0:00:10
    	progress: |================================------------------| 64.6% Complete  => 0:00:10
    	progress: |=================================-----------------| 65.2% Complete  => 0:00:10
    	progress: |=================================-----------------| 65.8% Complete  => 0:00:10
    	progress: |=================================-----------------| 66.5% Complete  => 0:00:10
    	progress: |==================================----------------| 67.1% Complete  => 0:00:10
    	progress: |==================================----------------| 67.7% Complete  => 0:00:10
    	progress: |==================================----------------| 68.3% Complete  => 0:00:10
    	progress: |==================================----------------| 68.9% Complete  => 0:00:10
    	progress: |===================================---------------| 69.6% Complete  => 0:00:10
    	progress: |===================================---------------| 70.2% Complete  => 0:00:10
    	progress: |===================================---------------| 70.8% Complete  => 0:00:10
    	progress: |====================================--------------| 71.4% Complete  => 0:00:10
    	progress: |====================================--------------| 72.0% Complete  => 0:00:10
    	progress: |====================================--------------| 72.7% Complete  => 0:00:10
    	progress: |=====================================-------------| 73.3% Complete  => 0:00:10
    	progress: |=====================================-------------| 73.9% Complete  => 0:00:10
    	progress: |=====================================-------------| 74.5% Complete  => 0:00:10
    	progress: |======================================------------| 75.2% Complete  => 0:00:10
    	progress: |======================================------------| 75.8% Complete  => 0:00:10
    	progress: |======================================------------| 76.4% Complete  => 0:00:10
    	progress: |=======================================-----------| 77.0% Complete  => 0:00:10
    	progress: |=======================================-----------| 77.6% Complete  => 0:00:10
    	progress: |=======================================-----------| 78.3% Complete  => 0:00:10
    	progress: |=======================================-----------| 78.9% Complete  => 0:00:10
    	progress: |========================================----------| 79.5% Complete  => 0:00:10
    	progress: |========================================----------| 80.1% Complete  => 0:00:10
    	progress: |========================================----------| 80.7% Complete  => 0:00:10
    	progress: |=========================================---------| 81.4% Complete  => 0:00:10
    	progress: |=========================================---------| 82.0% Complete  => 0:00:10
    	progress: |=========================================---------| 82.6% Complete  => 0:00:10
    	progress: |==========================================--------| 83.2% Complete  => 0:00:10
    	progress: |==========================================--------| 83.9% Complete  => 0:00:10
    	progress: |==========================================--------| 84.5% Complete  => 0:00:10
    	progress: |===========================================-------| 85.1% Complete  => 0:00:10
    	progress: |===========================================-------| 85.7% Complete  => 0:00:10
    	progress: |===========================================-------| 86.3% Complete  => 0:00:10
    	progress: |===========================================-------| 87.0% Complete  => 0:00:10
    	progress: |============================================------| 87.6% Complete  => 0:00:10
    	progress: |============================================------| 88.2% Complete  => 0:00:10
    	progress: |============================================------| 88.8% Complete  => 0:00:10
    	progress: |=============================================-----| 89.4% Complete  => 0:00:10
    	progress: |=============================================-----| 90.1% Complete  => 0:00:10
    	progress: |=============================================-----| 90.7% Complete  => 0:00:10
    	progress: |==============================================----| 91.3% Complete  => 0:00:10
    	progress: |==============================================----| 91.9% Complete  => 0:00:10
    	progress: |==============================================----| 92.5% Complete  => 0:00:10
    	progress: |===============================================---| 93.2% Complete  => 0:00:10
    	progress: |===============================================---| 93.8% Complete  => 0:00:10
    	progress: |===============================================---| 94.4% Complete  => 0:00:10
    	progress: |================================================--| 95.0% Complete  => 0:00:10
    	progress: |================================================--| 95.7% Complete  => 0:00:10
    	progress: |================================================--| 96.3% Complete  => 0:00:10
    	progress: |================================================--| 96.9% Complete  => 0:00:10
    	progress: |=================================================-| 97.5% Complete  => 0:00:10
    	progress: |=================================================-| 98.1% Complete  => 0:00:10
    	progress: |=================================================-| 98.8% Complete  => 0:00:10
    	progress: |==================================================| 99.4% Complete  => 0:00:10
    	progress: |==================================================| 100.0% Complete  => 0:00:10

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.9% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.3% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.8% Complete  => 0:00:00
    	progress: |==------------------------------------------------| 4.0% Complete  => 0:00:00
    	progress: |===-----------------------------------------------| 5.8% Complete  => 0:00:00
    	progress: |=====---------------------------------------------| 10.7% Complete  => 0:00:00
    	progress: |===========---------------------------------------| 21.3% Complete  => 0:00:00
    	progress: |==============------------------------------------| 28.9% Complete  => 0:00:00
    	progress: |======================----------------------------| 44.0% Complete  => 0:00:01
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:01
    	progress: |==================================================| 100.0% Complete  => 0:00:01
    2025/06/06 14:36:55:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/06 14:36:56:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/06 14:37:01:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/06 14:37:01:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:37:01:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:37:01:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_import_polymer 0:00:00.037670

Started | 2025-06-06 14:37:01
Ended | 2025-06-06 14:37:01
Duration | 0:00:00.037670
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_run_all_processors 0:01:22.283703

Started | 2025-06-06 14:37:01
Ended | 2025-06-06 14:38:23
Duration | 0:01:22.283703
Markers | skipif False reason='POLYMER is not installed.'
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': None,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpt8yv7ugw'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'combined',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '/root/polymer-v4.16.1',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spectral',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': True},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/06 14:37:01:   Reading metadata for VNIR detector...
    2025/06/06 14:37:01:   Calculating solar irradiance...
    2025/06/06 14:37:02:   Reading metadata for SWIR detector...
    2025/06/06 14:37:02:   Calculating solar irradiance...
    2025/06/06 14:37:02:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:37:02:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:37:02:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:37:02:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:37:02:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:37:02:   Computing VNIR geolayer...
    2025/06/06 14:37:03:   Computing SWIR geolayer...
    2025/06/06 14:37:03:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/06 14:37:03:   Percentage of defective pixels: 0.49
    2025/06/06 14:37:03:   Percentage of pixels with a defect in any band: 35.60
    2025/06/06 14:37:03:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/06 14:37:03:   Percentage of defective pixels: 0.50
    2025/06/06 14:37:03:   Percentage of pixels with a defect in any band: 44.50
    2025/06/06 14:37:03:   Pre-processing DEM for VNIR...
    2025/06/06 14:37:03:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/06/06 14:37:03:   Pre-processing DEM for SWIR...
    2025/06/06 14:37:03:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/06/06 14:37:03:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/06/06 14:37:03:   Starting atmospheric correction for VNIR and SWIR detector in 'combined' mode. Source radiometric unit code is 'TOARad'.
    2025/06/06 14:37:03:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 16,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': True,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/06/06 14:37:03:   Setting up forward operator...
    2025/06/06 14:37:03:   SICOR is applied to land pixels only. This may result in edge effects, e.g., at coastlines...
    2025/06/06 14:37:04:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/06/06 14:37:05:   Getting observation metadata...
    2025/06/06 14:37:05:   Checking if observation metadata values are within LUT value ranges...
    2025/06/06 14:37:05:   Loading solar irradiance model...
    2025/06/06 14:37:05:   Loading RT LUT...
    2025/06/06 14:37:05:   LUT file was properly downloaded and is available for AC!
    2025/06/06 14:37:05:   Converting LUT to Fontenla solar model...
    2025/06/06 14:37:05:   Resampling LUT to EnMAP wavelengths...
    2025/06/06 14:37:27:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/06/06 14:37:27:   Calculating absorption coefficients of liquid water and ice...
    2025/06/06 14:37:27:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/06/06 14:37:28:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/06/06 14:37:29:   Performing first guess liquid water retrieval based on the NDWI...
    2025/06/06 14:37:29:   Performing first guess ice retrieval based on the NDSI...
    2025/06/06 14:37:29:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/06/06 14:37:29:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/06/06 14:37:29:   Preparing segmented SWIR L1B data cube...
    2025/06/06 14:37:29:   Performing 3 phases of water retrieval...
    2025/06/06 14:37:29:   Setting up multiprocessing...
    2025/06/06 14:37:29:   Multiprocessing on 16 cpu's
    2025/06/06 14:37:29:   Preparing optimal estimation input...
    2025/06/06 14:37:29:   Optimization...
    2025/06/06 14:37:30:   Done!
    2025/06/06 14:37:30:   Runtime: 1.40 s
    2025/06/06 14:37:30:   Smoothing segmented CWV retrieval map...
    2025/06/06 14:37:30:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/06/06 14:37:31:   Starting surface reflectance retrieval...
    2025/06/06 14:37:31:   Calculating surface reflectance for vnir detector...
    2025/06/06 14:37:32:   Calculating surface reflectance for swir detector...
    2025/06/06 14:37:34:   Smoothing segmented liquid water and ice maps...
    2025/06/06 14:37:34:   SICOR atmospheric correction for EnMAP in combined mode successfully finished!
    vnir
    2025/06/06 14:37:34:   Running polymer...
    Initializing ENMAP product of size (30, 1000)
    2025/06/06 14:37:34:   Landmask is EnMAP L1B
    Starting processing at 2025-06-06 14:37:34.460368
    Processing block: size (30, 1000), offset (0, 0)
    Done in 0:00:43.158946
    2025/06/06 14:38:17:   Joining results of atmospheric correction.
    2025/06/06 14:38:17:   Re-applying dead pixel correction to correct for spectral spikes due to fringe effect.
    2025/06/06 14:38:17:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/06 14:38:17:   Percentage of defective pixels: 0.49
    2025/06/06 14:38:17:   Percentage of pixels with a defect in any band: 35.60
    2025/06/06 14:38:17:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/06 14:38:17:   Percentage of defective pixels: 0.50
    2025/06/06 14:38:17:   Percentage of pixels with a defect in any band: 44.50
    2025/06/06 14:38:18:   Starting orthorectification...
    2025/06/06 14:38:18:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (637410.0, 4942680.0, 666180.0, 4949340.0)
    2025/06/06 14:38:18:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:38:18:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:38:19:   Merging VNIR and SWIR data...
    2025/06/06 14:38:19:   Orthorectifying 'mask_landwater' attribute...
    2025/06/06 14:38:19:   Orthorectifying 'mask_clouds' attribute...
    2025/06/06 14:38:19:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/06 14:38:19:   Orthorectifying 'mask_haze' attribute...
    2025/06/06 14:38:19:   Orthorectifying 'mask_snow' attribute...
    2025/06/06 14:38:19:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/06 14:38:20:   Orthorectifying 'polymer_logchl' attribute...
    2025/06/06 14:38:20:   Orthorectifying 'polymer_logfb' attribute...
    2025/06/06 14:38:20:   Orthorectifying 'polymer_rgli' attribute...
    2025/06/06 14:38:20:   Orthorectifying 'polymer_rnir' attribute...
    2025/06/06 14:38:21:   Orthorectifying 'polymer_bitmask' attribute...
    2025/06/06 14:38:21:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/06 14:38:21:   Generating L2A metadata...
    2025/06/06 14:38:22:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (222, 959, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_LOGCHL.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_LOGFB.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_RGLI.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_RNIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_BITMASK.TIF.
    2025/06/06 14:38:23:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/06/06 14:38:23:   L2A product successfully written!
    2025/06/06 14:38:23:   Total runtime of the processing chain: 0:01:22.216773

##### Captured stderr call

    2025/06/06 14:37:01:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 2.4% Complete  => 0:00:00
    	progress: |===============-----------------------------------| 29.3% Complete  => 0:00:00
    	progress: |==================================================| 100.0% Complete  => 0:00:00
    2025/06/06 14:37:34:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/06 14:37:34:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/06 14:38:23:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/06 14:38:23:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:38:23:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:38:23:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_run_all_processors_without_acwater_installed 0:00:34.974294

Test to run all processors while replacing polymer_ac_enmap with None using mock.patch.

Started | 2025-06-06 14:38:23
Ended | 2025-06-06 14:38:58
Duration | 0:00:34.974294
Markers | skipif False reason='POLYMER is not installed.'
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': None,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmp061i6ily'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'combined',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '/root/polymer-v4.16.1',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spectral',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': True},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/06 14:38:24:   Reading metadata for VNIR detector...
    2025/06/06 14:38:24:   Calculating solar irradiance...
    2025/06/06 14:38:24:   Reading metadata for SWIR detector...
    2025/06/06 14:38:24:   Calculating solar irradiance...
    2025/06/06 14:38:24:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:38:24:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:38:24:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:38:24:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:38:25:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:38:25:   Computing VNIR geolayer...
    2025/06/06 14:38:25:   Computing SWIR geolayer...
    2025/06/06 14:38:25:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/06 14:38:25:   Percentage of defective pixels: 0.49
    2025/06/06 14:38:25:   Percentage of pixels with a defect in any band: 35.60
    2025/06/06 14:38:25:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/06 14:38:25:   Percentage of defective pixels: 0.50
    2025/06/06 14:38:25:   Percentage of pixels with a defect in any band: 44.50
    2025/06/06 14:38:25:   Pre-processing DEM for VNIR...
    2025/06/06 14:38:25:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/06/06 14:38:25:   Pre-processing DEM for SWIR...
    2025/06/06 14:38:25:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/06/06 14:38:25:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/06/06 14:38:26:   Starting atmospheric correction for VNIR and SWIR detector in 'combined' mode. Source radiometric unit code is 'TOARad'.
    2025/06/06 14:38:26:   Running atmospheric correction in 'land' mode, i.e., SICOR is applied to ALL surfaces. Uncertainty is expected for water surfaces because SICOR is designed for land only.
    2025/06/06 14:38:26:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 16,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': False,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/06/06 14:38:26:   Setting up forward operator...
    2025/06/06 14:38:26:   SICOR is applied to land AND water pixels.
    2025/06/06 14:38:26:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/06/06 14:38:27:   Getting observation metadata...
    2025/06/06 14:38:27:   Checking if observation metadata values are within LUT value ranges...
    2025/06/06 14:38:27:   Loading solar irradiance model...
    2025/06/06 14:38:27:   Loading RT LUT...
    2025/06/06 14:38:27:   LUT file was properly downloaded and is available for AC!
    2025/06/06 14:38:27:   Converting LUT to Fontenla solar model...
    2025/06/06 14:38:27:   Resampling LUT to EnMAP wavelengths...
    2025/06/06 14:38:47:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/06/06 14:38:47:   Calculating absorption coefficients of liquid water and ice...
    2025/06/06 14:38:47:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/06/06 14:38:48:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/06/06 14:38:48:   Performing first guess liquid water retrieval based on the NDWI...
    2025/06/06 14:38:48:   Performing first guess ice retrieval based on the NDSI...
    2025/06/06 14:38:48:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/06/06 14:38:48:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/06/06 14:38:48:   Preparing segmented SWIR L1B data cube...
    2025/06/06 14:38:49:   Performing 3 phases of water retrieval...
    2025/06/06 14:38:49:   Setting up multiprocessing...
    2025/06/06 14:38:49:   Multiprocessing on 16 cpu's
    2025/06/06 14:38:49:   Preparing optimal estimation input...
    2025/06/06 14:38:49:   Optimization...
    2025/06/06 14:38:51:   Done!
    2025/06/06 14:38:51:   Runtime: 2.15 s
    2025/06/06 14:38:51:   Smoothing segmented CWV retrieval map...
    2025/06/06 14:38:51:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/06/06 14:38:51:   Starting surface reflectance retrieval...
    2025/06/06 14:38:51:   Calculating surface reflectance for vnir detector...
    2025/06/06 14:38:53:   Calculating surface reflectance for swir detector...
    2025/06/06 14:38:54:   Smoothing segmented liquid water and ice maps...
    2025/06/06 14:38:55:   SICOR atmospheric correction for EnMAP in land mode successfully finished!
    2025/06/06 14:38:55:   Joining results of atmospheric correction.
    2025/06/06 14:38:55:   Re-applying dead pixel correction to correct for spectral spikes due to fringe effect.
    2025/06/06 14:38:55:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/06 14:38:55:   Percentage of defective pixels: 0.49
    2025/06/06 14:38:55:   Percentage of pixels with a defect in any band: 35.60
    2025/06/06 14:38:55:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/06 14:38:55:   Percentage of defective pixels: 0.50
    2025/06/06 14:38:55:   Percentage of pixels with a defect in any band: 44.50
    2025/06/06 14:38:55:   Starting orthorectification...
    2025/06/06 14:38:55:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (637410.0, 4942680.0, 666180.0, 4949340.0)
    2025/06/06 14:38:55:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:38:55:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:38:56:   Merging VNIR and SWIR data...
    2025/06/06 14:38:56:   Orthorectifying 'mask_landwater' attribute...
    2025/06/06 14:38:56:   Orthorectifying 'mask_clouds' attribute...
    2025/06/06 14:38:56:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/06 14:38:56:   Orthorectifying 'mask_haze' attribute...
    2025/06/06 14:38:57:   Orthorectifying 'mask_snow' attribute...
    2025/06/06 14:38:57:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/06 14:38:57:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/06 14:38:57:   Generating L2A metadata...
    2025/06/06 14:38:58:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (222, 959, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    2025/06/06 14:38:58:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/06/06 14:38:58:   L2A product successfully written!
    2025/06/06 14:38:58:   Total runtime of the processing chain: 0:00:34.927325

##### Captured stderr call

    2025/06/06 14:38:23:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/06/06 14:38:26:   Polymer is not callable. As a fallback, SICOR is applied to water surfaces instead.

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |==------------------------------------------------| 3.0% Complete  => 0:00:00
    	progress: |===-----------------------------------------------| 6.0% Complete  => 0:00:00
    	progress: |======--------------------------------------------| 12.7% Complete  => 0:00:00
    	progress: |========------------------------------------------| 15.1% Complete  => 0:00:00
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:00
    	progress: |===================-------------------------------| 38.6% Complete  => 0:00:00
    	progress: |===========================-----------------------| 54.2% Complete  => 0:00:01
    	progress: |==============================--------------------| 60.8% Complete  => 0:00:01
    	progress: |====================================--------------| 71.7% Complete  => 0:00:01
    	progress: |============================================------| 88.0% Complete  => 0:00:01
    	progress: |==================================================| 99.4% Complete  => 0:00:01
    	progress: |==================================================| 100.0% Complete  => 0:00:01
    2025/06/06 14:38:55:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/06 14:38:55:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/06 14:38:58:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/06 14:38:58:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:38:58:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:38:58:   The 'polymer_logchl' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:38:58:   The 'polymer_logfb' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:38:58:   The 'polymer_rgli' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:38:58:   The 'polymer_rnir' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:38:58:   The 'polymer_bitmask' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/06 14:38:58:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

## tests/test_dead_pixel_correction.py 15 0:00:07.910544

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_2D_deadpixelmap_spatial 0:00:03.733711

Started | 2025-06-06 14:38:58
Ended | 2025-06-06 14:39:02
Duration | 0:00:03.733711
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_2D_deadpixelmap_spectral 0:00:00.100696

Started | 2025-06-06 14:39:02
Ended | 2025-06-06 14:39:02
Duration | 0:00:00.100696
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_3D_deadpixelmap_spatial 0:00:03.818481

Started | 2025-06-06 14:39:02
Ended | 2025-06-06 14:39:06
Duration | 0:00:03.818481
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_3D_deadpixelmap_spectral 0:00:00.171288

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.171288
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_axis_0 0:00:00.003014

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.003014
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_axis_1 0:00:00.002635

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.002635
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_bad_args 0:00:00.001219

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.001219
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_2d 0:00:00.001955

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.001955
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_0 0:00:00.002730

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.002730
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_1 0:00:00.003481

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.003481
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_2 0:00:00.058693

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.058693
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_bad_args 0:00:00.001221

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.001221
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_bad_args 0:00:00.001258

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.001258
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_interpolation_pandas 0:00:00.005078

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.005078
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_interpolation_scipy 0:00:00.005085

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.005085
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_dem_preprocessing.py 8 0:00:00.399525

### PASSED Test_DEM_Processor::test_compute_aspect 0:00:00.061732

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.061732
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_compute_slopes 0:00:00.026012

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.026012
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_fill_gaps 0:00:00.028198

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.028198
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_get_flat_dem 0:00:00.034751

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.034751
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_demTooSmall 0:00:00.033223

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.033223
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_noWGS84 0:00:00.025684

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.025684
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_nomapinfo 0:00:00.023398

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:06
Duration | 0:00:00.023398
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_to_sensor_geometry 0:00:00.166529

Started | 2025-06-06 14:39:06
Ended | 2025-06-06 14:39:07
Duration | 0:00:00.166529
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_images_sensorgeo.py 6 0:00:25.082896

### PASSED Test_EnMAPL1Product_SensorGeo::test_set_SWIRattr_with_transformedVNIRattr 0:00:02.363607

Started | 2025-06-06 14:39:07
Ended | 2025-06-06 14:39:09
Duration | 0:00:02.363607
Markers |
Fixtures | request

#### Setup

##### Captured stdout setup

    2025/06/06 14:39:07:   Reading metadata for VNIR detector...
    2025/06/06 14:39:07:   Calculating solar irradiance...
    2025/06/06 14:39:07:   Reading metadata for SWIR detector...
    2025/06/06 14:39:08:   Calculating solar irradiance...
    2025/06/06 14:39:08:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:39:08:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:39:08:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:39:08:   Computing VNIR geolayer...
    2025/06/06 14:39:08:   Computing SWIR geolayer...

##### Captured stderr setup

    2025/06/06 14:39:07:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

#### Call

##### Captured stdout call

    2025/06/06 14:39:09:   Transforming the 'mask_snow' attribute from VNIR to SWIR sensor geometry.

##### Captured stderr call

    2025/06/06 14:39:09:   The mask_snow is not yet available in SWIR sensor geometry. Use EnMAP_SWIR_SensorGeo.transform_vnir_to_swir_raster() to set it with a transformed version of the one provided in VNIR sensor geometry.

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_set_SWIRattr_with_transformedVNIRattr__attrIsNone 0:00:00.008244

Started | 2025-06-06 14:39:09
Ended | 2025-06-06 14:39:09
Duration | 0:00:00.008244
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:39:09:   Transforming the 'mask_haze' attribute from VNIR to SWIR sensor geometry.

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_swir_to_vnir_raster__no_geolayer 0:00:00.010153

Started | 2025-06-06 14:39:09
Ended | 2025-06-06 14:39:09
Duration | 0:00:00.010153
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_swir_to_vnir_raster_no_keystone 0:00:01.899794

Started | 2025-06-06 14:39:09
Ended | 2025-06-06 14:39:11
Duration | 0:00:01.899794
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_vnir_to_swir_raster__no_geolayer 0:00:00.001318

Started | 2025-06-06 14:39:11
Ended | 2025-06-06 14:39:11
Duration | 0:00:00.001318
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_vnir_to_swir_raster_with_keystone 0:00:20.799780

Started | 2025-06-06 14:39:11
Ended | 2025-06-06 14:39:32
Duration | 0:00:20.799780
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_isofit_enmap.py 65 0:01:54.022756

### PASSED Test_ISOFIT_EnMAP::test__compute_cos_i 0:00:08.969555

Started | 2025-06-06 14:39:32
Ended | 2025-06-06 14:39:41
Duration | 0:00:08.969555
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:39:32:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/06 14:39:32:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/06 14:39:32:   LUT zipfile already downloaded. Proceeding.
    2025/06/06 14:39:32:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Pulling release v1.0.2
    Downloading file
    Unzipping /root/.isofit/isofit-data.zip
    Done, now available at: /root/.isofit/data
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Pulling release main/v1.2.7
    Downloading file
    Unzipping /root/.isofit/isofit-tutorials.zip
    Downloading NEON data for the example
    Output as: /root/.isofit/examples/isotuts/NEON/data
    Downloading file
    Unzipping /root/.isofit/examples/isotuts/NEON/NEON-subset-data.zip
    Done, now available at: /root/.isofit/examples
    [!] Be sure to build the examples for your system via `isofit build`

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test__compute_solar_phase 0:00:00.285777

Started | 2025-06-06 14:39:41
Ended | 2025-06-06 14:39:41
Duration | 0:00:00.285777
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:39:41:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/06 14:39:41:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/06 14:39:41:   LUT zipfile already downloaded. Proceeding.
    2025/06/06 14:39:41:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test__run__backtransformed_l2_spectra_6s 0:00:00.000736

4x3 spectra within 10x10 image. Lines: different forward sim.: #1: UVEG LUT; #2: Luis LUT, #3: MODTRAN.

Started | 2025-06-06 14:39:41
Ended | 2025-06-06 14:39:41
Duration | 0:00:00.000736
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 185, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test__run__backtransformed_l2_spectra_lut_mod5 0:01:06.685553

4x3 spectra within 10x10 image. Lines: different forward sim.: #1: UVEG LUT; #2: Luis LUT, #3: MODTRAN.

Started | 2025-06-06 14:39:41
Ended | 2025-06-06 14:40:48
Duration | 0:01:06.685553
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:39:41:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/06 14:39:41:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/06 14:39:41:   LUT zipfile already downloaded. Proceeding.
    2025/06/06 14:39:41:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    2025/06/06 14:39:41:   Generating LUT file...
    2025/06/06 14:39:52:   Flightline ID: 20220717T110603Z
    2025/06/06 14:39:52:   no noise path found, proceeding without
    2025/06/06 14:39:52:   Running ISOFIT...
    2025/06/06 14:39:52:   Loading config file: /tmp/tmpipf8qppt/workdir/config/isofit_config.json
    2025/06/06 14:39:52:   Checking config sections for configuration issues
    2025/06/06 14:39:52:   Configuration file checks complete, no errors found.
    2025/06/06 14:40:01:   Building first forward model, will generate any necessary LUTs
    2025/06/06 14:40:01:   Loading from wavelength_file: /tmp/tmpipf8qppt/extracted/backtransformed_l2_spectra_v9/enmap_wavelengths.txt
    2025/06/06 14:40:01:   Prebuilt LUT provided
    2025/06/06 14:40:08:   Loading LUT into memory
    2025/06/06 14:40:08:   LUT grid loaded from file: OrderedDict({'AERFRAC_2': [0.05, 0.12, 0.2, 0.3, 0.4, 0.8], 'H2OSTR': [0.0, 1.0, 1.5, 2.0, 2.7, 3.5, 5.0], 'observer_zenith': [0, 10.0, 20.0, 30.0, 40.0], 'relative_azimuth': [0, 25.0, 50.0, 85.0, 120.0, 155.0, 180.0], 'solar_zenith': [0, 10.0, 20.0, 35.0, 50.0, 70.0], 'surface_elevation_km': [0, 0.7, 2.5, 8.0]})
    2025/06/06 14:40:31:   Beginning 100 inversions in 100 chunks using 20 cores
    2025/06/06 14:40:46:   Inversions complete.  14.69s total, 6.8091 spectra/s, 0.3405 spectra/s/core
    2025/06/06 14:40:46:   ISOFIT finished.
    2025/06/06 14:40:46:   Stopping ray.

##### Captured stderr call

    2025/06/06 14:39:52:
    ******************************************************************************************
    ! Number of threads is greater than 1 (currently: 24), this may greatly impact performance
    ! Please set this the environment variables 'MKL_NUM_THREADS' and 'OMP_NUM_THREADS' to '1'
    ******************************************************************************************
    2025-06-06 14:39:56,638	WARNING services.py:2070 -- WARNING: The object store is using /tmp instead of /dev/shm because /dev/shm has only 66887680 bytes available. This will harm performance! You may be able to free up space by deleting files in /dev/shm. If you are inside a Docker container, you can increase /dev/shm size by passing '--shm-size=10.24gb' to 'docker run' (or add it to the run_options list in a Ray cluster config). Make sure to set this to more than 30% of available RAM.
    2025-06-06 14:39:57,931	INFO worker.py:1852 -- Started a local Ray instance.
    WARNING: All log messages before absl::InitializeLog() is called are written to STDERR
    I0000 00:00:1749220846.626718     862 chttp2_transport.cc:1182] ipv4:172.17.0.14:58445: Got goaway [2] err=UNAVAILABLE:GOAWAY received; Error code: 2; Debug Text: Cancelling all calls {grpc_status:14, http2_error:2, created_time:"2025-06-06T14:40:46.626702149+00:00"}

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_apply_oe__direct_call 0:00:00.000574

Started | 2025-06-06 14:40:48
Ended | 2025-06-06 14:40:48
Duration | 0:00:00.000574
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 120, 'Skipped: too slow for running in CI')

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_apply_oe_on_map_geometry 0:00:00.000472

Started | 2025-06-06 14:40:48
Ended | 2025-06-06 14:40:48
Duration | 0:00:00.000472
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 154, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test_download_isofit_resources 0:00:02.344302

Started | 2025-06-06 14:40:48
Ended | 2025-06-06 14:40:50
Duration | 0:00:02.344302
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:40:48:   ISOFIT surface spectra zipfile successfully downloaded.
    2025/06/06 14:40:50:   LUT zipfile successfully downloaded.
    2025/06/06 14:40:50:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/06 14:40:50:   LUT zipfile already downloaded. Proceeding.

##### Captured log call

    INFO     test_downloads:_isofit_downloads.py:83 ISOFIT surface spectra zipfile successfully downloaded.
    INFO     test_downloads:_isofit_downloads.py:83 LUT zipfile successfully downloaded.
    INFO     test_downloads:_isofit_downloads.py:87 ISOFIT surface spectra zipfile already downloaded. Proceeding.
    INFO     test_downloads:_isofit_downloads.py:87 LUT zipfile already downloaded. Proceeding.

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test_generate_input_files 0:00:23.104680

Started | 2025-06-06 14:40:50
Ended | 2025-06-06 14:41:13
Duration | 0:00:23.104680
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:40:50:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/06 14:40:50:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/06 14:40:50:   LUT zipfile already downloaded. Proceeding.
    2025/06/06 14:40:50:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    2025/06/06 14:40:50:   Reading Input Data
    2025/06/06 14:40:51:   Reading metadata for VNIR detector...
    2025/06/06 14:40:51:   Calculating solar irradiance...
    2025/06/06 14:40:51:   Reading metadata for SWIR detector...
    2025/06/06 14:40:51:   Calculating solar irradiance...
    2025/06/06 14:40:51:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:40:52:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:40:52:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:40:52:   Computing VNIR geolayer...
    2025/06/06 14:40:52:   Computing SWIR geolayer...
    2025/06/06 14:40:52:   Starting orthorectification...
    2025/06/06 14:40:52:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636990.0, 4940640.0, 666180.0, 4949340.0)
    2025/06/06 14:40:52:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:40:53:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:40:54:   Merging VNIR and SWIR data...
    2025/06/06 14:40:54:   Orthorectifying 'mask_landwater' attribute...
    2025/06/06 14:40:55:   Orthorectifying 'mask_clouds' attribute...
    2025/06/06 14:40:55:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/06 14:40:55:   Orthorectifying 'mask_haze' attribute...
    2025/06/06 14:40:55:   Orthorectifying 'mask_snow' attribute...
    2025/06/06 14:40:56:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/06 14:40:56:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/06 14:40:57:   Generating L2A metadata...
    2025/06/06 14:40:57:   Generating radiance file...
    Writing GeoArray of size (290, 973, 202) to /tmp/tmpwdvozstd/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_rdn.
    2025/06/06 14:40:59:   Generating location file...
    2025/06/06 14:40:59:   Pre-processing DEM in map geometry...
    Automatically detected nodata value for GeoArray 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER': 0.0
    Writing GeoArray of size (290, 973, 3) to /tmp/tmpwdvozstd/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_loc.
    2025/06/06 14:40:59:   Generating observation file...
    Writing GeoArray of size (290, 973, 11) to /tmp/tmpwdvozstd/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_obs.
    2025/06/06 14:40:59:   Generating wavelength file...
    2025/06/06 14:40:59:   Generating surface file for default set of surface coverage types...
    0 ['filtered_other']
    0 ['filtered_veg']
    0 ['filtered_ocean']
    0 ['surface_Liquids']
    1 ['surface_Liquids']
    2025/06/06 14:41:02:   Generating LUT file...

##### Captured stderr call

    2025/06/06 14:40:51:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.2% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.0% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.1% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.0% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.1% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.1% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.0% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.0% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.0% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.2% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.0% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.0% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.0% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.1% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.0% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.0% Complete  => 0:00:00
    Warping progress     |============================================------| 87.1% Complete  => 0:00:00
    Warping progress     |============================================------| 88.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.0% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.0% Complete  => 0:00:00
    Warping progress     |================================================--| 96.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.0% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.0% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_run_on_map_geometry 0:00:00.000643

Started | 2025-06-06 14:41:13
Ended | 2025-06-06 14:41:13
Duration | 0:00:00.000643
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 213, 'Skipped: too slow for running in CI')

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_run_on_map_geometry_no_segmentation 0:00:00.000848

Started | 2025-06-06 14:41:13
Ended | 2025-06-06 14:41:13
Duration | 0:00:00.000848
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 217, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_LUTTransformer::test_modtran_lut_to_netcdf 0:00:12.629616

Started | 2025-06-06 14:41:13
Ended | 2025-06-06 14:41:26
Duration | 0:00:12.629616
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stderr call

    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")

#### Teardown

## tests/test_l1b_reader.py 10 0:01:48.973357

### PASSED Test_L1B_Reader::test_append_100_lines 0:00:17.481285

Started | 2025-06-06 14:41:26
Ended | 2025-06-06 14:41:43
Duration | 0:00:17.481285
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:41:27:   Reading Input Data
    2025/06/06 14:41:27:   Reading metadata for VNIR detector...
    2025/06/06 14:41:27:   Calculating solar irradiance...
    2025/06/06 14:41:27:   Reading metadata for SWIR detector...
    2025/06/06 14:41:27:   Calculating solar irradiance...
    2025/06/06 14:41:27:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:27:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:27:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:27:   Reading metadata for VNIR detector...
    2025/06/06 14:41:28:   Calculating solar irradiance...
    2025/06/06 14:41:28:   Reading metadata for SWIR detector...
    2025/06/06 14:41:28:   Calculating solar irradiance...
    2025/06/06 14:41:28:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:28:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:28:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:28:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:28:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:28:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:28:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:28:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk5xjq9r8/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk5xjq9r8/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk5xjq9r8/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk5xjq9r8/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk5xjq9r8/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk5xjq9r8/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk5xjq9r8/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk5xjq9r8/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:41:29:   L1B product successfully written!
    2025/06/06 14:41:29:   Reading Input Data
    2025/06/06 14:41:29:   Reading metadata for VNIR detector...
    2025/06/06 14:41:29:   Calculating solar irradiance...
    2025/06/06 14:41:29:   Reading metadata for SWIR detector...
    2025/06/06 14:41:29:   Calculating solar irradiance...
    2025/06/06 14:41:29:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:29:   Reading Input Data
    2025/06/06 14:41:29:   Reading metadata for VNIR detector...
    2025/06/06 14:41:30:   Calculating solar irradiance...
    2025/06/06 14:41:30:   Reading metadata for SWIR detector...
    2025/06/06 14:41:30:   Calculating solar irradiance...
    2025/06/06 14:41:30:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:30:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:30:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:30:   Reading metadata for VNIR detector...
    2025/06/06 14:41:30:   Calculating solar irradiance...
    2025/06/06 14:41:30:   Reading metadata for SWIR detector...
    2025/06/06 14:41:31:   Calculating solar irradiance...
    2025/06/06 14:41:31:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:31:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:31:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:31:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:31:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:31:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:31:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:31:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:41:33:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:41:33:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqjksmlbc/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqjksmlbc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqjksmlbc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqjksmlbc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqjksmlbc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqjksmlbc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqjksmlbc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqjksmlbc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:41:33:   L1B product successfully written!
    2025/06/06 14:41:33:   Reading Input Data
    2025/06/06 14:41:33:   Reading metadata for VNIR detector...
    2025/06/06 14:41:34:   Calculating solar irradiance...
    2025/06/06 14:41:34:   Reading metadata for SWIR detector...
    2025/06/06 14:41:34:   Calculating solar irradiance...
    2025/06/06 14:41:34:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:34:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:41:36:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:41:36:   Reading Input Data
    2025/06/06 14:41:36:   Reading metadata for VNIR detector...
    2025/06/06 14:41:36:   Calculating solar irradiance...
    2025/06/06 14:41:36:   Reading metadata for SWIR detector...
    2025/06/06 14:41:37:   Calculating solar irradiance...
    2025/06/06 14:41:37:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:37:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:37:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:37:   Reading metadata for VNIR detector...
    2025/06/06 14:41:37:   Calculating solar irradiance...
    2025/06/06 14:41:37:   Reading metadata for SWIR detector...
    2025/06/06 14:41:37:   Calculating solar irradiance...
    2025/06/06 14:41:37:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:37:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:38:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:38:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:41:38:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:41:38:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcra8g5il/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcra8g5il/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcra8g5il/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcra8g5il/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcra8g5il/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcra8g5il/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcra8g5il/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcra8g5il/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/06 14:41:38:   L1B product successfully written!
    2025/06/06 14:41:38:   Reading Input Data
    2025/06/06 14:41:38:   Reading metadata for VNIR detector...
    2025/06/06 14:41:38:   Calculating solar irradiance...
    2025/06/06 14:41:38:   Reading metadata for SWIR detector...
    2025/06/06 14:41:38:   Calculating solar irradiance...
    2025/06/06 14:41:39:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:39:   Reading Input Data
    2025/06/06 14:41:39:   Reading metadata for VNIR detector...
    2025/06/06 14:41:39:   Calculating solar irradiance...
    2025/06/06 14:41:39:   Reading metadata for SWIR detector...
    2025/06/06 14:41:39:   Calculating solar irradiance...
    2025/06/06 14:41:39:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:39:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:39:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:40:   Reading metadata for VNIR detector...
    2025/06/06 14:41:40:   Calculating solar irradiance...
    2025/06/06 14:41:40:   Reading metadata for SWIR detector...
    2025/06/06 14:41:40:   Calculating solar irradiance...
    2025/06/06 14:41:40:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:40:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:40:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:40:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:41:40:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:41:40:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:41:41:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:41:41:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx8a4nwa1/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx8a4nwa1/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx8a4nwa1/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx8a4nwa1/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx8a4nwa1/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx8a4nwa1/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx8a4nwa1/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx8a4nwa1/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/06 14:41:42:   L1B product successfully written!
    2025/06/06 14:41:42:   Reading Input Data
    2025/06/06 14:41:42:   Reading metadata for VNIR detector...
    2025/06/06 14:41:42:   Calculating solar irradiance...
    2025/06/06 14:41:42:   Reading metadata for SWIR detector...
    2025/06/06 14:41:42:   Calculating solar irradiance...
    2025/06/06 14:41:42:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:42:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:41:43:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    2025/06/06 14:41:28:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/06 14:41:28:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/06 14:41:28:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/06 14:41:28:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/06 14:41:28:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/06 14:41:28:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:41:28:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:41:28:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:41:28:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:41:28:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:41:31:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/06 14:41:31:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/06 14:41:31:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/06 14:41:31:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/06 14:41:31:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/06 14:41:33:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:41:33:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:41:33:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:41:33:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:41:33:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:41:38:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:41:38:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:41:38:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:41:38:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:41:38:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:41:38:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:41:38:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:41:40:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:41:40:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:41:41:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:41:41:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:41:41:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:41:41:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:41:41:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_10_lines 0:00:15.379752

Started | 2025-06-06 14:41:43
Ended | 2025-06-06 14:41:59
Duration | 0:00:15.379752
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:41:44:   Reading Input Data
    2025/06/06 14:41:44:   Reading metadata for VNIR detector...
    2025/06/06 14:41:44:   Calculating solar irradiance...
    2025/06/06 14:41:44:   Reading metadata for SWIR detector...
    2025/06/06 14:41:44:   Calculating solar irradiance...
    2025/06/06 14:41:44:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:44:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:45:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:45:   Reading metadata for VNIR detector...
    2025/06/06 14:41:45:   Calculating solar irradiance...
    2025/06/06 14:41:45:   Reading metadata for SWIR detector...
    2025/06/06 14:41:45:   Calculating solar irradiance...
    2025/06/06 14:41:45:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:45:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:45:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:46:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:46:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:46:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:46:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:46:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyc15ke7h/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyc15ke7h/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyc15ke7h/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyc15ke7h/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyc15ke7h/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyc15ke7h/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyc15ke7h/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyc15ke7h/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:41:46:   L1B product successfully written!
    2025/06/06 14:41:46:   Reading Input Data
    2025/06/06 14:41:46:   Reading metadata for VNIR detector...
    2025/06/06 14:41:46:   Calculating solar irradiance...
    2025/06/06 14:41:46:   Reading metadata for SWIR detector...
    2025/06/06 14:41:46:   Calculating solar irradiance...
    2025/06/06 14:41:46:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:46:   Reading Input Data
    2025/06/06 14:41:47:   Reading metadata for VNIR detector...
    2025/06/06 14:41:47:   Calculating solar irradiance...
    2025/06/06 14:41:47:   Reading metadata for SWIR detector...
    2025/06/06 14:41:47:   Calculating solar irradiance...
    2025/06/06 14:41:47:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:47:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:47:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:47:   Reading metadata for VNIR detector...
    2025/06/06 14:41:48:   Calculating solar irradiance...
    2025/06/06 14:41:48:   Reading metadata for SWIR detector...
    2025/06/06 14:41:48:   Calculating solar irradiance...
    2025/06/06 14:41:48:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:48:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:48:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:48:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:48:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:48:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:48:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:41:48:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:41:49:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:41:50:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpucsg1494/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpucsg1494/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpucsg1494/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpucsg1494/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpucsg1494/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpucsg1494/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpucsg1494/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpucsg1494/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:41:50:   L1B product successfully written!
    2025/06/06 14:41:50:   Reading Input Data
    2025/06/06 14:41:50:   Reading metadata for VNIR detector...
    2025/06/06 14:41:50:   Calculating solar irradiance...
    2025/06/06 14:41:50:   Reading metadata for SWIR detector...
    2025/06/06 14:41:50:   Calculating solar irradiance...
    2025/06/06 14:41:50:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:50:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:41:52:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:41:52:   Reading Input Data
    2025/06/06 14:41:52:   Reading metadata for VNIR detector...
    2025/06/06 14:41:52:   Calculating solar irradiance...
    2025/06/06 14:41:52:   Reading metadata for SWIR detector...
    2025/06/06 14:41:53:   Calculating solar irradiance...
    2025/06/06 14:41:53:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:53:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:53:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:53:   Reading metadata for VNIR detector...
    2025/06/06 14:41:53:   Calculating solar irradiance...
    2025/06/06 14:41:53:   Reading metadata for SWIR detector...
    2025/06/06 14:41:53:   Calculating solar irradiance...
    2025/06/06 14:41:53:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:53:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:53:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:54:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:41:54:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:41:54:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_0z97dy/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_0z97dy/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_0z97dy/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_0z97dy/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_0z97dy/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_0z97dy/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_0z97dy/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_0z97dy/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/06 14:41:54:   L1B product successfully written!
    2025/06/06 14:41:54:   Reading Input Data
    2025/06/06 14:41:54:   Reading metadata for VNIR detector...
    2025/06/06 14:41:54:   Calculating solar irradiance...
    2025/06/06 14:41:54:   Reading metadata for SWIR detector...
    2025/06/06 14:41:54:   Calculating solar irradiance...
    2025/06/06 14:41:54:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:54:   Reading Input Data
    2025/06/06 14:41:55:   Reading metadata for VNIR detector...
    2025/06/06 14:41:55:   Calculating solar irradiance...
    2025/06/06 14:41:55:   Reading metadata for SWIR detector...
    2025/06/06 14:41:55:   Calculating solar irradiance...
    2025/06/06 14:41:55:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:55:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:55:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:55:   Reading metadata for VNIR detector...
    2025/06/06 14:41:55:   Calculating solar irradiance...
    2025/06/06 14:41:55:   Reading metadata for SWIR detector...
    2025/06/06 14:41:56:   Calculating solar irradiance...
    2025/06/06 14:41:56:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:56:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:41:56:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:41:56:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:41:56:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:41:56:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:41:57:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:41:57:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_l0vpzx2/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_l0vpzx2/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_l0vpzx2/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_l0vpzx2/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_l0vpzx2/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_l0vpzx2/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_l0vpzx2/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_l0vpzx2/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/06 14:41:57:   L1B product successfully written!
    2025/06/06 14:41:57:   Reading Input Data
    2025/06/06 14:41:57:   Reading metadata for VNIR detector...
    2025/06/06 14:41:57:   Calculating solar irradiance...
    2025/06/06 14:41:57:   Reading metadata for SWIR detector...
    2025/06/06 14:41:58:   Calculating solar irradiance...
    2025/06/06 14:41:58:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:41:58:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:41:58:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/06 14:41:46:   A minimum of 50 lines is required, only 10 were selected
    2025/06/06 14:41:46:   Set the number of line to 50
    2025/06/06 14:41:46:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/06 14:41:46:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/06 14:41:46:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/06 14:41:46:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/06 14:41:46:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/06 14:41:46:   A minimum of 50 lines is required, only 10 were selected
    2025/06/06 14:41:46:   Set the number of line to 50
    2025/06/06 14:41:46:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:41:46:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:41:46:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:41:46:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:41:46:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:41:48:   A minimum of 50 lines is required, only 10 were selected
    2025/06/06 14:41:48:   Set the number of line to 50
    2025/06/06 14:41:48:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/06 14:41:48:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/06 14:41:48:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/06 14:41:48:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/06 14:41:48:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/06 14:41:48:   A minimum of 50 lines is required, only 10 were selected
    2025/06/06 14:41:48:   Set the number of line to 50
    2025/06/06 14:41:50:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:41:50:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:41:50:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:41:50:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:41:50:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:41:54:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:41:54:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:41:54:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:41:54:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:41:54:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:41:54:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:41:54:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:41:56:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:41:56:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:41:57:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:41:57:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:41:57:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:41:57:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:41:57:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_150_lines 0:00:16.520922

Started | 2025-06-06 14:41:59
Ended | 2025-06-06 14:42:15
Duration | 0:00:16.520922
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:41:59:   Reading Input Data
    2025/06/06 14:41:59:   Reading metadata for VNIR detector...
    2025/06/06 14:42:00:   Calculating solar irradiance...
    2025/06/06 14:42:00:   Reading metadata for SWIR detector...
    2025/06/06 14:42:00:   Calculating solar irradiance...
    2025/06/06 14:42:00:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:00:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:00:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:00:   Reading metadata for VNIR detector...
    2025/06/06 14:42:00:   Calculating solar irradiance...
    2025/06/06 14:42:00:   Reading metadata for SWIR detector...
    2025/06/06 14:42:01:   Calculating solar irradiance...
    2025/06/06 14:42:01:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:01:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:01:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:01:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:01:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:01:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:01:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:01:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbou67wnl/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbou67wnl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbou67wnl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbou67wnl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbou67wnl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbou67wnl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbou67wnl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpbou67wnl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:42:01:   L1B product successfully written!
    2025/06/06 14:42:01:   Reading Input Data
    2025/06/06 14:42:01:   Reading metadata for VNIR detector...
    2025/06/06 14:42:02:   Calculating solar irradiance...
    2025/06/06 14:42:02:   Reading metadata for SWIR detector...
    2025/06/06 14:42:02:   Calculating solar irradiance...
    2025/06/06 14:42:02:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:02:   Reading Input Data
    2025/06/06 14:42:02:   Reading metadata for VNIR detector...
    2025/06/06 14:42:02:   Calculating solar irradiance...
    2025/06/06 14:42:02:   Reading metadata for SWIR detector...
    2025/06/06 14:42:03:   Calculating solar irradiance...
    2025/06/06 14:42:03:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:03:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:03:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:03:   Reading metadata for VNIR detector...
    2025/06/06 14:42:03:   Calculating solar irradiance...
    2025/06/06 14:42:03:   Reading metadata for SWIR detector...
    2025/06/06 14:42:03:   Calculating solar irradiance...
    2025/06/06 14:42:03:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:03:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:04:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:04:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:04:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:04:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:04:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:04:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:42:05:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:42:05:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpdpm48k5i/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpdpm48k5i/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpdpm48k5i/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpdpm48k5i/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpdpm48k5i/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpdpm48k5i/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpdpm48k5i/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpdpm48k5i/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:42:06:   L1B product successfully written!
    2025/06/06 14:42:06:   Reading Input Data
    2025/06/06 14:42:06:   Reading metadata for VNIR detector...
    2025/06/06 14:42:06:   Calculating solar irradiance...
    2025/06/06 14:42:06:   Reading metadata for SWIR detector...
    2025/06/06 14:42:06:   Calculating solar irradiance...
    2025/06/06 14:42:06:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:07:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:42:08:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:42:08:   Reading Input Data
    2025/06/06 14:42:08:   Reading metadata for VNIR detector...
    2025/06/06 14:42:09:   Calculating solar irradiance...
    2025/06/06 14:42:09:   Reading metadata for SWIR detector...
    2025/06/06 14:42:09:   Calculating solar irradiance...
    2025/06/06 14:42:09:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:09:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:09:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:09:   Reading metadata for VNIR detector...
    2025/06/06 14:42:09:   Calculating solar irradiance...
    2025/06/06 14:42:09:   Reading metadata for SWIR detector...
    2025/06/06 14:42:10:   Calculating solar irradiance...
    2025/06/06 14:42:10:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:10:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:10:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:10:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:42:10:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:42:10:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9vpms6zm/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9vpms6zm/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9vpms6zm/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9vpms6zm/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9vpms6zm/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9vpms6zm/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9vpms6zm/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9vpms6zm/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/06 14:42:10:   L1B product successfully written!
    2025/06/06 14:42:10:   Reading Input Data
    2025/06/06 14:42:10:   Reading metadata for VNIR detector...
    2025/06/06 14:42:10:   Calculating solar irradiance...
    2025/06/06 14:42:11:   Reading metadata for SWIR detector...
    2025/06/06 14:42:11:   Calculating solar irradiance...
    2025/06/06 14:42:11:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:11:   Reading Input Data
    2025/06/06 14:42:11:   Reading metadata for VNIR detector...
    2025/06/06 14:42:11:   Calculating solar irradiance...
    2025/06/06 14:42:11:   Reading metadata for SWIR detector...
    2025/06/06 14:42:11:   Calculating solar irradiance...
    2025/06/06 14:42:11:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:11:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:11:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:12:   Reading metadata for VNIR detector...
    2025/06/06 14:42:12:   Calculating solar irradiance...
    2025/06/06 14:42:12:   Reading metadata for SWIR detector...
    2025/06/06 14:42:12:   Calculating solar irradiance...
    2025/06/06 14:42:12:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:12:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:12:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:12:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:42:12:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:42:12:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:42:13:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:42:13:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3rbt_fk7/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3rbt_fk7/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3rbt_fk7/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3rbt_fk7/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3rbt_fk7/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3rbt_fk7/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3rbt_fk7/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3rbt_fk7/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/06 14:42:13:   L1B product successfully written!
    2025/06/06 14:42:13:   Reading Input Data
    2025/06/06 14:42:14:   Reading metadata for VNIR detector...
    2025/06/06 14:42:14:   Calculating solar irradiance...
    2025/06/06 14:42:14:   Reading metadata for SWIR detector...
    2025/06/06 14:42:14:   Calculating solar irradiance...
    2025/06/06 14:42:14:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:14:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:42:15:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/06 14:42:01:   n_lines (150) exceeds the total number of line of second image
    2025/06/06 14:42:01:   Set to the image number of line
    2025/06/06 14:42:01:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/06 14:42:01:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/06 14:42:01:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/06 14:42:01:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/06 14:42:01:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/06 14:42:01:   n_lines (150) exceeds the total number of line of second image
    2025/06/06 14:42:01:   Set to the image number of line
    2025/06/06 14:42:01:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:42:01:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:42:01:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:42:01:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:42:01:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:42:04:   n_lines (150) exceeds the total number of line of second image
    2025/06/06 14:42:04:   Set to the image number of line
    2025/06/06 14:42:04:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/06 14:42:04:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/06 14:42:04:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/06 14:42:04:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/06 14:42:04:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/06 14:42:04:   n_lines (150) exceeds the total number of line of second image
    2025/06/06 14:42:04:   Set to the image number of line
    2025/06/06 14:42:06:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:42:06:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:42:06:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:42:06:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:42:06:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:42:10:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:42:10:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:42:10:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:42:10:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:42:10:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:42:10:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:42:10:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:42:12:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:42:12:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:42:13:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:42:13:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:42:13:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:42:13:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:42:13:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_50_lines 0:00:17.504136

Started | 2025-06-06 14:42:15
Ended | 2025-06-06 14:42:33
Duration | 0:00:17.504136
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:42:16:   Reading Input Data
    2025/06/06 14:42:16:   Reading metadata for VNIR detector...
    2025/06/06 14:42:16:   Calculating solar irradiance...
    2025/06/06 14:42:16:   Reading metadata for SWIR detector...
    2025/06/06 14:42:16:   Calculating solar irradiance...
    2025/06/06 14:42:16:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:16:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:16:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:17:   Reading metadata for VNIR detector...
    2025/06/06 14:42:17:   Calculating solar irradiance...
    2025/06/06 14:42:17:   Reading metadata for SWIR detector...
    2025/06/06 14:42:17:   Calculating solar irradiance...
    2025/06/06 14:42:17:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:17:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:17:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:17:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:17:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:17:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:17:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:17:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1y31vq5i/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1y31vq5i/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1y31vq5i/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1y31vq5i/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1y31vq5i/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1y31vq5i/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1y31vq5i/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1y31vq5i/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:42:18:   L1B product successfully written!
    2025/06/06 14:42:18:   Reading Input Data
    2025/06/06 14:42:18:   Reading metadata for VNIR detector...
    2025/06/06 14:42:18:   Calculating solar irradiance...
    2025/06/06 14:42:18:   Reading metadata for SWIR detector...
    2025/06/06 14:42:18:   Calculating solar irradiance...
    2025/06/06 14:42:18:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:18:   Reading Input Data
    2025/06/06 14:42:19:   Reading metadata for VNIR detector...
    2025/06/06 14:42:19:   Calculating solar irradiance...
    2025/06/06 14:42:19:   Reading metadata for SWIR detector...
    2025/06/06 14:42:19:   Calculating solar irradiance...
    2025/06/06 14:42:19:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:19:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:19:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:20:   Reading metadata for VNIR detector...
    2025/06/06 14:42:20:   Calculating solar irradiance...
    2025/06/06 14:42:20:   Reading metadata for SWIR detector...
    2025/06/06 14:42:20:   Calculating solar irradiance...
    2025/06/06 14:42:20:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:21:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:21:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:21:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:21:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:21:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:21:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:21:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:42:23:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:42:23:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpod10zsyw/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpod10zsyw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpod10zsyw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpod10zsyw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpod10zsyw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpod10zsyw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpod10zsyw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpod10zsyw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:42:24:   L1B product successfully written!
    2025/06/06 14:42:24:   Reading Input Data
    2025/06/06 14:42:24:   Reading metadata for VNIR detector...
    2025/06/06 14:42:24:   Calculating solar irradiance...
    2025/06/06 14:42:24:   Reading metadata for SWIR detector...
    2025/06/06 14:42:24:   Calculating solar irradiance...
    2025/06/06 14:42:24:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:24:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:42:25:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:42:26:   Reading Input Data
    2025/06/06 14:42:26:   Reading metadata for VNIR detector...
    2025/06/06 14:42:26:   Calculating solar irradiance...
    2025/06/06 14:42:26:   Reading metadata for SWIR detector...
    2025/06/06 14:42:26:   Calculating solar irradiance...
    2025/06/06 14:42:26:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:26:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:26:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:27:   Reading metadata for VNIR detector...
    2025/06/06 14:42:27:   Calculating solar irradiance...
    2025/06/06 14:42:27:   Reading metadata for SWIR detector...
    2025/06/06 14:42:27:   Calculating solar irradiance...
    2025/06/06 14:42:27:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:27:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:27:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:27:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:42:27:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:42:27:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppirah1e_/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppirah1e_/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppirah1e_/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppirah1e_/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppirah1e_/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppirah1e_/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppirah1e_/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppirah1e_/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/06 14:42:28:   L1B product successfully written!
    2025/06/06 14:42:28:   Reading Input Data
    2025/06/06 14:42:28:   Reading metadata for VNIR detector...
    2025/06/06 14:42:28:   Calculating solar irradiance...
    2025/06/06 14:42:28:   Reading metadata for SWIR detector...
    2025/06/06 14:42:28:   Calculating solar irradiance...
    2025/06/06 14:42:28:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:28:   Reading Input Data
    2025/06/06 14:42:28:   Reading metadata for VNIR detector...
    2025/06/06 14:42:29:   Calculating solar irradiance...
    2025/06/06 14:42:29:   Reading metadata for SWIR detector...
    2025/06/06 14:42:29:   Calculating solar irradiance...
    2025/06/06 14:42:29:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:29:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:29:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:29:   Reading metadata for VNIR detector...
    2025/06/06 14:42:29:   Calculating solar irradiance...
    2025/06/06 14:42:29:   Reading metadata for SWIR detector...
    2025/06/06 14:42:30:   Calculating solar irradiance...
    2025/06/06 14:42:30:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:30:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:30:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:30:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:42:30:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:42:30:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:42:31:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:42:31:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfvt0ocpd/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfvt0ocpd/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfvt0ocpd/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfvt0ocpd/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfvt0ocpd/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfvt0ocpd/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfvt0ocpd/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfvt0ocpd/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/06 14:42:31:   L1B product successfully written!
    2025/06/06 14:42:31:   Reading Input Data
    2025/06/06 14:42:31:   Reading metadata for VNIR detector...
    2025/06/06 14:42:31:   Calculating solar irradiance...
    2025/06/06 14:42:31:   Reading metadata for SWIR detector...
    2025/06/06 14:42:32:   Calculating solar irradiance...
    2025/06/06 14:42:32:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:32:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:42:32:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/06 14:42:17:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/06 14:42:17:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/06 14:42:17:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/06 14:42:17:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/06 14:42:17:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/06 14:42:18:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:42:18:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:42:18:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:42:18:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:42:18:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:42:21:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/06 14:42:21:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/06 14:42:21:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/06 14:42:21:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/06 14:42:21:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/06 14:42:23:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:42:23:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:42:23:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:42:23:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:42:23:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:42:27:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:42:27:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:42:27:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:42:27:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:42:27:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:42:27:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:42:27:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:42:30:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:42:30:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:42:31:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:42:31:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:42:31:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:42:31:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:42:31:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_80_lines 0:00:15.972551

Started | 2025-06-06 14:42:33
Ended | 2025-06-06 14:42:49
Duration | 0:00:15.972551
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:42:33:   Reading Input Data
    2025/06/06 14:42:33:   Reading metadata for VNIR detector...
    2025/06/06 14:42:34:   Calculating solar irradiance...
    2025/06/06 14:42:34:   Reading metadata for SWIR detector...
    2025/06/06 14:42:34:   Calculating solar irradiance...
    2025/06/06 14:42:34:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:34:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:34:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:34:   Reading metadata for VNIR detector...
    2025/06/06 14:42:34:   Calculating solar irradiance...
    2025/06/06 14:42:34:   Reading metadata for SWIR detector...
    2025/06/06 14:42:35:   Calculating solar irradiance...
    2025/06/06 14:42:35:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:35:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:35:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:35:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:35:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:35:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:35:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:35:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptrzefj33/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (180, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptrzefj33/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (180, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptrzefj33/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptrzefj33/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptrzefj33/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (180, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptrzefj33/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptrzefj33/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptrzefj33/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:42:35:   L1B product successfully written!
    2025/06/06 14:42:35:   Reading Input Data
    2025/06/06 14:42:35:   Reading metadata for VNIR detector...
    2025/06/06 14:42:36:   Calculating solar irradiance...
    2025/06/06 14:42:36:   Reading metadata for SWIR detector...
    2025/06/06 14:42:36:   Calculating solar irradiance...
    2025/06/06 14:42:36:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:36:   Reading Input Data
    2025/06/06 14:42:36:   Reading metadata for VNIR detector...
    2025/06/06 14:42:36:   Calculating solar irradiance...
    2025/06/06 14:42:36:   Reading metadata for SWIR detector...
    2025/06/06 14:42:36:   Calculating solar irradiance...
    2025/06/06 14:42:37:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:37:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:37:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:37:   Reading metadata for VNIR detector...
    2025/06/06 14:42:37:   Calculating solar irradiance...
    2025/06/06 14:42:37:   Reading metadata for SWIR detector...
    2025/06/06 14:42:37:   Calculating solar irradiance...
    2025/06/06 14:42:37:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:37:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:37:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:38:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:38:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:38:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:38:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:38:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:42:39:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:42:39:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplbanhill/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (180, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplbanhill/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (180, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplbanhill/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplbanhill/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplbanhill/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (180, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplbanhill/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplbanhill/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplbanhill/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:42:40:   L1B product successfully written!
    2025/06/06 14:42:40:   Reading Input Data
    2025/06/06 14:42:40:   Reading metadata for VNIR detector...
    2025/06/06 14:42:40:   Calculating solar irradiance...
    2025/06/06 14:42:40:   Reading metadata for SWIR detector...
    2025/06/06 14:42:40:   Calculating solar irradiance...
    2025/06/06 14:42:40:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:40:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:42:42:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:42:42:   Reading Input Data
    2025/06/06 14:42:42:   Reading metadata for VNIR detector...
    2025/06/06 14:42:42:   Calculating solar irradiance...
    2025/06/06 14:42:42:   Reading metadata for SWIR detector...
    2025/06/06 14:42:42:   Calculating solar irradiance...
    2025/06/06 14:42:42:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:42:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:42:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:43:   Reading metadata for VNIR detector...
    2025/06/06 14:42:43:   Calculating solar irradiance...
    2025/06/06 14:42:43:   Reading metadata for SWIR detector...
    2025/06/06 14:42:43:   Calculating solar irradiance...
    2025/06/06 14:42:43:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:43:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:43:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:43:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:42:43:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:42:43:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpsqymk1ob/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpsqymk1ob/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpsqymk1ob/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpsqymk1ob/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpsqymk1ob/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpsqymk1ob/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpsqymk1ob/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpsqymk1ob/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/06 14:42:44:   L1B product successfully written!
    2025/06/06 14:42:44:   Reading Input Data
    2025/06/06 14:42:44:   Reading metadata for VNIR detector...
    2025/06/06 14:42:44:   Calculating solar irradiance...
    2025/06/06 14:42:44:   Reading metadata for SWIR detector...
    2025/06/06 14:42:44:   Calculating solar irradiance...
    2025/06/06 14:42:44:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:44:   Reading Input Data
    2025/06/06 14:42:44:   Reading metadata for VNIR detector...
    2025/06/06 14:42:45:   Calculating solar irradiance...
    2025/06/06 14:42:45:   Reading metadata for SWIR detector...
    2025/06/06 14:42:45:   Calculating solar irradiance...
    2025/06/06 14:42:45:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:45:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:45:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:45:   Reading metadata for VNIR detector...
    2025/06/06 14:42:45:   Calculating solar irradiance...
    2025/06/06 14:42:45:   Reading metadata for SWIR detector...
    2025/06/06 14:42:46:   Calculating solar irradiance...
    2025/06/06 14:42:46:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:46:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:46:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:46:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:42:46:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:42:46:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:42:47:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:42:47:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68v6p_wh/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68v6p_wh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68v6p_wh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68v6p_wh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68v6p_wh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68v6p_wh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68v6p_wh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp68v6p_wh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/06 14:42:47:   L1B product successfully written!
    2025/06/06 14:42:47:   Reading Input Data
    2025/06/06 14:42:47:   Reading metadata for VNIR detector...
    2025/06/06 14:42:47:   Calculating solar irradiance...
    2025/06/06 14:42:47:   Reading metadata for SWIR detector...
    2025/06/06 14:42:47:   Calculating solar irradiance...
    2025/06/06 14:42:48:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:48:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:42:48:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/06 14:42:35:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/06 14:42:35:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/06 14:42:35:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/06 14:42:35:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/06 14:42:35:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/06 14:42:35:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:42:35:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:42:35:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:42:35:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:42:35:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:42:38:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/06 14:42:38:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/06 14:42:38:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/06 14:42:38:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/06 14:42:38:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/06 14:42:39:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:42:39:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:42:39:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:42:39:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:42:39:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:42:43:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:42:43:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:42:43:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:42:43:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:42:43:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:42:43:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:42:43:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:42:46:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:42:46:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:42:47:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:42:47:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:42:47:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:42:47:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:42:47:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_all_lines 0:00:16.445029

Started | 2025-06-06 14:42:49
Ended | 2025-06-06 14:43:05
Duration | 0:00:16.445029
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:42:49:   Reading Input Data
    2025/06/06 14:42:49:   Reading metadata for VNIR detector...
    2025/06/06 14:42:50:   Calculating solar irradiance...
    2025/06/06 14:42:50:   Reading metadata for SWIR detector...
    2025/06/06 14:42:50:   Calculating solar irradiance...
    2025/06/06 14:42:50:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:50:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:50:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:50:   Reading metadata for VNIR detector...
    2025/06/06 14:42:50:   Calculating solar irradiance...
    2025/06/06 14:42:50:   Reading metadata for SWIR detector...
    2025/06/06 14:42:51:   Calculating solar irradiance...
    2025/06/06 14:42:51:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:51:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:51:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:51:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:51:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:51:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:51:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:51:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8dluazbd/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8dluazbd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8dluazbd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8dluazbd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8dluazbd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8dluazbd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8dluazbd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8dluazbd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:42:51:   L1B product successfully written!
    2025/06/06 14:42:51:   Reading Input Data
    2025/06/06 14:42:52:   Reading metadata for VNIR detector...
    2025/06/06 14:42:52:   Calculating solar irradiance...
    2025/06/06 14:42:52:   Reading metadata for SWIR detector...
    2025/06/06 14:42:52:   Calculating solar irradiance...
    2025/06/06 14:42:52:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:52:   Reading Input Data
    2025/06/06 14:42:52:   Reading metadata for VNIR detector...
    2025/06/06 14:42:52:   Calculating solar irradiance...
    2025/06/06 14:42:52:   Reading metadata for SWIR detector...
    2025/06/06 14:42:53:   Calculating solar irradiance...
    2025/06/06 14:42:53:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:53:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:53:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:53:   Reading metadata for VNIR detector...
    2025/06/06 14:42:53:   Calculating solar irradiance...
    2025/06/06 14:42:53:   Reading metadata for SWIR detector...
    2025/06/06 14:42:53:   Calculating solar irradiance...
    2025/06/06 14:42:53:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:53:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:54:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:54:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:54:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:54:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:54:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/06 14:42:54:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:42:55:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:42:55:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5oa_a8eh/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5oa_a8eh/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5oa_a8eh/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5oa_a8eh/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5oa_a8eh/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5oa_a8eh/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5oa_a8eh/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5oa_a8eh/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:42:56:   L1B product successfully written!
    2025/06/06 14:42:56:   Reading Input Data
    2025/06/06 14:42:56:   Reading metadata for VNIR detector...
    2025/06/06 14:42:56:   Calculating solar irradiance...
    2025/06/06 14:42:56:   Reading metadata for SWIR detector...
    2025/06/06 14:42:56:   Calculating solar irradiance...
    2025/06/06 14:42:56:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:57:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:42:58:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:42:58:   Reading Input Data
    2025/06/06 14:42:58:   Reading metadata for VNIR detector...
    2025/06/06 14:42:59:   Calculating solar irradiance...
    2025/06/06 14:42:59:   Reading metadata for SWIR detector...
    2025/06/06 14:42:59:   Calculating solar irradiance...
    2025/06/06 14:42:59:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:42:59:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:42:59:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:42:59:   Reading metadata for VNIR detector...
    2025/06/06 14:42:59:   Calculating solar irradiance...
    2025/06/06 14:42:59:   Reading metadata for SWIR detector...
    2025/06/06 14:43:00:   Calculating solar irradiance...
    2025/06/06 14:43:00:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:00:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:43:00:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:43:00:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:43:00:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:43:00:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp713skud6/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp713skud6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp713skud6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp713skud6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp713skud6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp713skud6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp713skud6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp713skud6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/06 14:43:00:   L1B product successfully written!
    2025/06/06 14:43:00:   Reading Input Data
    2025/06/06 14:43:00:   Reading metadata for VNIR detector...
    2025/06/06 14:43:00:   Calculating solar irradiance...
    2025/06/06 14:43:00:   Reading metadata for SWIR detector...
    2025/06/06 14:43:01:   Calculating solar irradiance...
    2025/06/06 14:43:01:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:01:   Reading Input Data
    2025/06/06 14:43:01:   Reading metadata for VNIR detector...
    2025/06/06 14:43:01:   Calculating solar irradiance...
    2025/06/06 14:43:01:   Reading metadata for SWIR detector...
    2025/06/06 14:43:01:   Calculating solar irradiance...
    2025/06/06 14:43:01:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:01:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:43:02:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:43:02:   Reading metadata for VNIR detector...
    2025/06/06 14:43:02:   Calculating solar irradiance...
    2025/06/06 14:43:02:   Reading metadata for SWIR detector...
    2025/06/06 14:43:02:   Calculating solar irradiance...
    2025/06/06 14:43:02:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:02:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:43:02:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:43:02:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:43:02:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/06 14:43:02:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:43:03:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:43:03:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_pyhsyhk/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_pyhsyhk/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_pyhsyhk/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_pyhsyhk/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_pyhsyhk/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_pyhsyhk/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_pyhsyhk/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_pyhsyhk/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/06 14:43:04:   L1B product successfully written!
    2025/06/06 14:43:04:   Reading Input Data
    2025/06/06 14:43:04:   Reading metadata for VNIR detector...
    2025/06/06 14:43:04:   Calculating solar irradiance...
    2025/06/06 14:43:04:   Reading metadata for SWIR detector...
    2025/06/06 14:43:04:   Calculating solar irradiance...
    2025/06/06 14:43:04:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:04:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:43:05:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/06 14:42:51:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/06 14:42:51:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/06 14:42:51:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/06 14:42:51:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/06 14:42:51:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/06 14:42:51:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:42:51:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:42:51:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:42:51:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:42:51:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:42:54:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/06 14:42:54:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/06 14:42:54:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/06 14:42:54:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/06 14:42:54:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/06 14:42:56:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:42:56:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:42:56:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:42:56:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:42:56:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:43:00:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:43:00:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:43:00:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:43:00:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:43:00:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:43:00:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:43:00:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/06 14:43:02:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:43:02:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/06 14:43:03:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:43:03:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:43:03:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:43:03:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:43:03:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_read_and_save_single_image_no_snr 0:00:02.422103

Test to read test image 1, save it and read the saved result again - without SNR.

Started | 2025-06-06 14:43:05
Ended | 2025-06-06 14:43:08
Duration | 0:00:02.422103
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:43:06:   Reading Input Data
    2025/06/06 14:43:06:   Reading metadata for VNIR detector...
    2025/06/06 14:43:06:   Calculating solar irradiance...
    2025/06/06 14:43:06:   Reading metadata for SWIR detector...
    2025/06/06 14:43:06:   Calculating solar irradiance...
    2025/06/06 14:43:06:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:06:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:43:06:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:43:07:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp33hojuis/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp33hojuis/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp33hojuis/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp33hojuis/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp33hojuis/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp33hojuis/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp33hojuis/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp33hojuis/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:43:07:   L1B product successfully written!
    2025/06/06 14:43:07:   Reading Input Data
    2025/06/06 14:43:07:   Reading metadata for VNIR detector...
    2025/06/06 14:43:07:   Calculating solar irradiance...
    2025/06/06 14:43:07:   Reading metadata for SWIR detector...
    2025/06/06 14:43:07:   Calculating solar irradiance...
    2025/06/06 14:43:07:   Reading image masks in VNIR sensor geometry.

##### Captured stderr call

    2025/06/06 14:43:07:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:43:07:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:43:07:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:43:07:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:43:07:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_read_and_save_single_image_with_snr 0:00:03.170784

Test to read test image 1, save it and read the saved result again - with SNR.

Started | 2025-06-06 14:43:08
Ended | 2025-06-06 14:43:11
Duration | 0:00:03.170784
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:43:08:   Reading Input Data
    2025/06/06 14:43:08:   Reading metadata for VNIR detector...
    2025/06/06 14:43:08:   Calculating solar irradiance...
    2025/06/06 14:43:08:   Reading metadata for SWIR detector...
    2025/06/06 14:43:09:   Calculating solar irradiance...
    2025/06/06 14:43:09:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:09:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:43:09:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:43:09:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:43:10:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:43:10:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzkxb1d9m/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzkxb1d9m/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzkxb1d9m/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzkxb1d9m/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzkxb1d9m/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzkxb1d9m/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzkxb1d9m/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzkxb1d9m/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/06 14:43:10:   L1B product successfully written!
    2025/06/06 14:43:10:   Reading Input Data
    2025/06/06 14:43:10:   Reading metadata for VNIR detector...
    2025/06/06 14:43:10:   Calculating solar irradiance...
    2025/06/06 14:43:10:   Reading metadata for SWIR detector...
    2025/06/06 14:43:11:   Calculating solar irradiance...
    2025/06/06 14:43:11:   Reading image masks in VNIR sensor geometry.

##### Captured stderr call

    2025/06/06 14:43:10:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/06 14:43:10:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/06 14:43:10:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/06 14:43:10:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/06 14:43:10:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader_DLR::test_read_inputdata 0:00:02.333270

Started | 2025-06-06 14:43:11
Ended | 2025-06-06 14:43:13
Duration | 0:00:02.333270
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:43:11:   Reading Input Data
    2025/06/06 14:43:11:   Reading metadata for VNIR detector...
    2025/06/06 14:43:11:   Calculating solar irradiance...
    2025/06/06 14:43:11:   Reading metadata for SWIR detector...
    2025/06/06 14:43:12:   Calculating solar irradiance...
    2025/06/06 14:43:12:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:12:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:43:12:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:43:12:   Computing VNIR geolayer...
    2025/06/06 14:43:12:   Computing SWIR geolayer...
    2025/06/06 14:43:13:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE_VNIR.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_PIXELMASK_VNIR.TIF.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.png.
    Writing GeoArray of size (100, 1000, 124) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE_SWIR.TIF.
    Writing GeoArray of size (100, 1000, 124) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_PIXELMASK_SWIR.TIF.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.png.
    2025/06/06 14:43:13:   L1B product successfully written!

##### Captured stderr call

    2025/06/06 14:43:11:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader_DLR::test_read_inputdata_dont_drop_bad_bands 0:00:01.743525

Started | 2025-06-06 14:43:13
Ended | 2025-06-06 14:43:15
Duration | 0:00:01.743525
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:43:13:   Reading Input Data
    2025/06/06 14:43:13:   Reading metadata for VNIR detector...
    2025/06/06 14:43:14:   Calculating solar irradiance...
    2025/06/06 14:43:14:   Reading metadata for SWIR detector...
    2025/06/06 14:43:14:   Calculating solar irradiance...
    2025/06/06 14:43:14:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:14:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:43:14:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:43:14:   Computing VNIR geolayer...
    2025/06/06 14:43:15:   Computing SWIR geolayer...

##### Captured stderr call

    2025/06/06 14:43:13:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_orthorectification.py 10 0:00:25.357683

### PASSED Test_Orthorectifier::test_run_transformation_ll 0:00:05.651152

Started | 2025-06-06 14:43:15
Ended | 2025-06-06 14:43:20
Duration | 0:00:05.651152
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:43:15:   Reading Input Data
    2025/06/06 14:43:15:   Reading metadata for VNIR detector...
    2025/06/06 14:43:15:   Calculating solar irradiance...
    2025/06/06 14:43:15:   Reading metadata for SWIR detector...
    2025/06/06 14:43:16:   Calculating solar irradiance...
    2025/06/06 14:43:16:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:16:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:43:16:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:43:16:   Starting orthorectification...
    2025/06/06 14:43:16:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 4326): (10.691214991975885, 47.455058810417405, 11.070768, 47.540321)
    2025/06/06 14:43:16:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:43:17:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:43:18:   Merging VNIR and SWIR data...
    2025/06/06 14:43:18:   Orthorectifying 'mask_clouds' attribute...
    2025/06/06 14:43:18:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/06 14:43:19:   Generating L2A metadata...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier::test_run_transformation_utm 0:00:06.096945

Started | 2025-06-06 14:43:20
Ended | 2025-06-06 14:43:27
Duration | 0:00:06.096945
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:43:21:   Reading Input Data
    2025/06/06 14:43:21:   Reading metadata for VNIR detector...
    2025/06/06 14:43:21:   Calculating solar irradiance...
    2025/06/06 14:43:21:   Reading metadata for SWIR detector...
    2025/06/06 14:43:22:   Calculating solar irradiance...
    2025/06/06 14:43:22:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:22:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:43:22:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:43:22:   Starting orthorectification...
    2025/06/06 14:43:22:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32632): (627300.0, 5257770.0, 656040.0, 5266620.0)
    2025/06/06 14:43:22:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:43:23:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:43:25:   Merging VNIR and SWIR data...
    2025/06/06 14:43:25:   Orthorectifying 'mask_clouds' attribute...
    2025/06/06 14:43:25:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/06 14:43:26:   Generating L2A metadata...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier_DLR::test_run_transformation_ll 0:00:06.751433

Started | 2025-06-06 14:43:27
Ended | 2025-06-06 14:43:33
Duration | 0:00:06.751433
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:43:27:   Reading Input Data
    2025/06/06 14:43:27:   Reading metadata for VNIR detector...
    2025/06/06 14:43:27:   Calculating solar irradiance...
    2025/06/06 14:43:27:   Reading metadata for SWIR detector...
    2025/06/06 14:43:27:   Calculating solar irradiance...
    2025/06/06 14:43:27:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:28:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:43:28:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:43:28:   Computing VNIR geolayer...
    2025/06/06 14:43:28:   Computing SWIR geolayer...
    2025/06/06 14:43:28:   Starting orthorectification...
    2025/06/06 14:43:28:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 4326): (-1.2717290915354968, 44.60009471477741, -0.9054060033197534, 44.68406888113938)
    2025/06/06 14:43:28:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:43:29:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:43:30:   Merging VNIR and SWIR data...
    2025/06/06 14:43:31:   Orthorectifying 'mask_landwater' attribute...
    2025/06/06 14:43:31:   Orthorectifying 'mask_clouds' attribute...
    2025/06/06 14:43:31:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/06 14:43:31:   Orthorectifying 'mask_haze' attribute...
    2025/06/06 14:43:31:   Orthorectifying 'mask_snow' attribute...
    2025/06/06 14:43:32:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/06 14:43:32:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/06 14:43:32:   Generating L2A metadata...

##### Captured stderr call

    2025/06/06 14:43:27:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier_DLR::test_run_transformation_utm 0:00:06.841369

Started | 2025-06-06 14:43:33
Ended | 2025-06-06 14:43:40
Duration | 0:00:06.841369
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:43:33:   Reading Input Data
    2025/06/06 14:43:34:   Reading metadata for VNIR detector...
    2025/06/06 14:43:34:   Calculating solar irradiance...
    2025/06/06 14:43:34:   Reading metadata for SWIR detector...
    2025/06/06 14:43:34:   Calculating solar irradiance...
    2025/06/06 14:43:34:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:35:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:43:35:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:43:35:   Computing VNIR geolayer...
    2025/06/06 14:43:35:   Computing SWIR geolayer...
    2025/06/06 14:43:35:   Starting orthorectification...
    2025/06/06 14:43:35:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636990.0, 4940640.0, 666180.0, 4949340.0)
    2025/06/06 14:43:35:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:43:36:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/06 14:43:37:   Merging VNIR and SWIR data...
    2025/06/06 14:43:37:   Orthorectifying 'mask_landwater' attribute...
    2025/06/06 14:43:38:   Orthorectifying 'mask_clouds' attribute...
    2025/06/06 14:43:38:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/06 14:43:38:   Orthorectifying 'mask_haze' attribute...
    2025/06/06 14:43:38:   Orthorectifying 'mask_snow' attribute...
    2025/06/06 14:43:38:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/06 14:43:39:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/06 14:43:39:   Generating L2A metadata...

##### Captured stderr call

    2025/06/06 14:43:34:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_compute_stack 0:00:00.003587

Started | 2025-06-06 14:43:40
Ended | 2025-06-06 14:43:40
Duration | 0:00:00.003587
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_average 0:00:00.003195

Started | 2025-06-06 14:43:40
Ended | 2025-06-06 14:43:40
Duration | 0:00:00.003195
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_order_by_wvl 0:00:00.002271

Started | 2025-06-06 14:43:40
Ended | 2025-06-06 14:43:40
Duration | 0:00:00.002271
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_swir_only 0:00:00.002023

Started | 2025-06-06 14:43:40
Ended | 2025-06-06 14:43:40
Duration | 0:00:00.002023
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_vnir_only 0:00:00.001983

Started | 2025-06-06 14:43:40
Ended | 2025-06-06 14:43:40
Duration | 0:00:00.001983
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_validate_input 0:00:00.003723

Started | 2025-06-06 14:43:40
Ended | 2025-06-06 14:43:40
Duration | 0:00:00.003723
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_radiometric_transform.py 1 0:00:04.361093

### PASSED Test_Radiometric_Transformer::test_transform_TOARad2TOARef 0:00:04.361093

Started | 2025-06-06 14:43:40
Ended | 2025-06-06 14:43:45
Duration | 0:00:04.361093
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Tmp dir: /tmp/tmpv8kom424
    2025/06/06 14:43:40:   Reading Input Data
    2025/06/06 14:43:41:   Reading metadata for VNIR detector...
    2025/06/06 14:43:41:   Calculating solar irradiance...
    2025/06/06 14:43:41:   Reading metadata for SWIR detector...
    2025/06/06 14:43:41:   Calculating solar irradiance...
    2025/06/06 14:43:41:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:41:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:43:41:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:43:41:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:43:42:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:43:42:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/06/06 14:43:42:   Converting TOA radiance to TOA reflectance for SWIR detector...
    Tmp dir: /tmp/tmpgds67khd
    2025/06/06 14:43:43:   Reading Input Data
    2025/06/06 14:43:43:   Reading metadata for VNIR detector...
    2025/06/06 14:43:43:   Calculating solar irradiance...
    2025/06/06 14:43:43:   Reading metadata for SWIR detector...
    2025/06/06 14:43:43:   Calculating solar irradiance...
    2025/06/06 14:43:43:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:43:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:43:43:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:43:43:   Computing SNR from VNIR TOA radiance.
    2025/06/06 14:43:44:   Computing SNR from SWIR TOA radiance.
    2025/06/06 14:43:44:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/06/06 14:43:44:   Converting TOA radiance to TOA reflectance for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_spatial_optimization.py 1 0:00:16.471605

### PASSED Test_Spatial_Optimizer::test_optimize_geolayer 0:00:16.471605

Started | 2025-06-06 14:43:45
Ended | 2025-06-06 14:44:01
Duration | 0:00:16.471605
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:43:45:   Reading Input Data
    2025/06/06 14:43:45:   Reading metadata for VNIR detector...
    2025/06/06 14:43:45:   Calculating solar irradiance...
    2025/06/06 14:43:45:   Reading metadata for SWIR detector...
    2025/06/06 14:43:45:   Calculating solar irradiance...
    2025/06/06 14:43:45:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:43:46:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:43:46:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:43:46:   Computing VNIR geolayer...
    2025/06/06 14:43:46:   Computing SWIR geolayer...
    2025/06/06 14:43:46:   Temporarily transforming EnMAP band 40 to map geometry for co-registration.
    2025/06/06 14:43:47:   Temporarily transforming EnMAP water mask to map geometry for co-registration.
    2025/06/06 14:43:47:   Preparing reference image for co-registration.
    2025/06/06 14:43:47:   Computing tie points between the EnMAP image and the given spatial reference image.
    Calculating footprint polygon and actual data corner coordinates for reference image...
    Bounding box of calculated footprint for reference image:
    	(637005.0, 4940640.0, 666300.0, 4949895.0)
    Bounding box of calculated footprint for image to be shifted:
    	(637009.9236523756, 4940648.633479693, 666298.6703669054, 4949893.375184522)
    Matching window position (X,Y): 651655.4222751356/4945271.096554121
    Target window size (256, 256) not possible due to too small overlap area or window position too close to an image edge. New matching window size: (164, 164).
    Initializing tie points grid...
    With respect to the provided bad data mask(s) 81 points of initially 242 have been excluded.
    Calculating tie point grid (161 points) using 24 CPU cores...
    Found 131 matches.
    Performing validity checks...
    41 tie points flagged by level 1 filtering (reliability).
    63 tie points flagged by level 2 filtering (SSIM).
    4 tie points flagged by level 3 filtering (RANSAC)
    47 valid tie points remain after filtering.
    2025/06/06 14:44:00:   Generating misregistration array.
    interpolation runtime: 0.22s
    interpolation runtime: 0.20s
    2025/06/06 14:44:00:   Transforming spatial optimization results back to sensor geometry.
    2025/06/06 14:44:01:   Applying results of spatial optimization to geolayer.

##### Captured stderr call

    2025/06/06 14:43:45:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/06/06 14:43:46:   Statically using band 40 for co-registration.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.1% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.2% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.2% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.0% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.6% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.1% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.1% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.2% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.4% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.3% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.3% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.3% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.4% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.2% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.2% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.1% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.3% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.2% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.5% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.4% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.3% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 27.1% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 28.0% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 29.0% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 30.3% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 31.3% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 32.1% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 33.1% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 34.0% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 35.5% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 36.5% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 37.3% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 38.6% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 39.5% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 40.4% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 41.0% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 42.3% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 43.1% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 44.2% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 45.2% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 46.0% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 47.2% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 48.3% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 49.1% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 50.4% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 51.1% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 52.2% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 53.2% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 54.1% Complete  => 0:00:00
    Warping progress     |============================----------------------| 55.3% Complete  => 0:00:00
    Warping progress     |============================----------------------| 56.2% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.1% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 58.3% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 59.2% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 60.1% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 61.4% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 62.2% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.2% Complete  => 0:00:00
    Warping progress     |================================------------------| 64.0% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 65.2% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.3% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.2% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.0% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.2% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.2% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.3% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.1% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.0% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.0% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.5% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.2% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.2% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.2% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.3% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.3% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.4% Complete  => 0:00:00
    Warping progress     |============================================------| 87.0% Complete  => 0:00:00
    Warping progress     |============================================------| 88.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.3% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.2% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.2% Complete  => 0:00:00
    Warping progress     |================================================--| 95.1% Complete  => 0:00:00
    Warping progress     |================================================--| 96.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.1% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:10
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:10
    	progress: |=-------------------------------------------------| 1.9% Complete  => 0:00:10
    	progress: |=-------------------------------------------------| 2.5% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 3.7% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 4.3% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 5.0% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 5.6% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 6.2% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 6.8% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 7.5% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 8.1% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 8.7% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 9.3% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 9.9% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 10.6% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 11.2% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 11.8% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 12.4% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 13.0% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 13.7% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 14.3% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 14.9% Complete  => 0:00:11
    	progress: |========------------------------------------------| 15.5% Complete  => 0:00:11
    	progress: |========------------------------------------------| 16.1% Complete  => 0:00:11
    	progress: |========------------------------------------------| 16.8% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 17.4% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 18.0% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 18.6% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 19.3% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 19.9% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 22.4% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 23.0% Complete  => 0:00:11
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:11
    	progress: |============--------------------------------------| 24.2% Complete  => 0:00:11
    	progress: |============--------------------------------------| 24.8% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 25.5% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 26.1% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:11
    	progress: |==============------------------------------------| 27.3% Complete  => 0:00:11
    	progress: |==============------------------------------------| 28.0% Complete  => 0:00:11
    	progress: |==============------------------------------------| 28.6% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 29.2% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 29.8% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 30.4% Complete  => 0:00:11
    	progress: |================----------------------------------| 31.1% Complete  => 0:00:11
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:11
    	progress: |================----------------------------------| 32.3% Complete  => 0:00:11
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:11
    	progress: |=================---------------------------------| 33.5% Complete  => 0:00:11
    	progress: |=================---------------------------------| 34.2% Complete  => 0:00:11
    	progress: |=================---------------------------------| 34.8% Complete  => 0:00:11
    	progress: |==================--------------------------------| 35.4% Complete  => 0:00:11
    	progress: |==================--------------------------------| 36.0% Complete  => 0:00:11
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:11
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:11
    	progress: |===================-------------------------------| 37.9% Complete  => 0:00:11
    	progress: |===================-------------------------------| 38.5% Complete  => 0:00:11
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:11
    	progress: |====================------------------------------| 39.8% Complete  => 0:00:11
    	progress: |====================------------------------------| 40.4% Complete  => 0:00:11
    	progress: |====================------------------------------| 41.0% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 41.6% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 42.9% Complete  => 0:00:11
    	progress: |======================----------------------------| 43.5% Complete  => 0:00:11
    	progress: |======================----------------------------| 44.1% Complete  => 0:00:11
    	progress: |======================----------------------------| 44.7% Complete  => 0:00:11
    	progress: |=======================---------------------------| 45.3% Complete  => 0:00:11
    	progress: |=======================---------------------------| 46.0% Complete  => 0:00:11
    	progress: |=======================---------------------------| 46.6% Complete  => 0:00:11
    	progress: |========================--------------------------| 47.2% Complete  => 0:00:11
    	progress: |========================--------------------------| 47.8% Complete  => 0:00:11
    	progress: |========================--------------------------| 48.4% Complete  => 0:00:11
    	progress: |=========================-------------------------| 49.1% Complete  => 0:00:11
    	progress: |=========================-------------------------| 49.7% Complete  => 0:00:11
    	progress: |=========================-------------------------| 50.3% Complete  => 0:00:11
    	progress: |=========================-------------------------| 50.9% Complete  => 0:00:11
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:11
    	progress: |==========================------------------------| 52.2% Complete  => 0:00:11
    	progress: |==========================------------------------| 52.8% Complete  => 0:00:11
    	progress: |===========================-----------------------| 53.4% Complete  => 0:00:11
    	progress: |===========================-----------------------| 54.0% Complete  => 0:00:11
    	progress: |===========================-----------------------| 54.7% Complete  => 0:00:11
    	progress: |============================----------------------| 55.3% Complete  => 0:00:11
    	progress: |============================----------------------| 55.9% Complete  => 0:00:11
    	progress: |============================----------------------| 56.5% Complete  => 0:00:11
    	progress: |=============================---------------------| 57.1% Complete  => 0:00:11
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:11
    	progress: |=============================---------------------| 58.4% Complete  => 0:00:11
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:11
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:11
    	progress: |==============================--------------------| 60.2% Complete  => 0:00:11
    	progress: |==============================--------------------| 60.9% Complete  => 0:00:11
    	progress: |===============================-------------------| 61.5% Complete  => 0:00:11
    	progress: |===============================-------------------| 62.1% Complete  => 0:00:11
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:11
    	progress: |================================------------------| 63.4% Complete  => 0:00:11
    	progress: |================================------------------| 64.0% Complete  => 0:00:11
    	progress: |================================------------------| 64.6% Complete  => 0:00:11
    	progress: |=================================-----------------| 65.2% Complete  => 0:00:11
    	progress: |=================================-----------------| 65.8% Complete  => 0:00:11
    	progress: |=================================-----------------| 66.5% Complete  => 0:00:11
    	progress: |==================================----------------| 67.1% Complete  => 0:00:11
    	progress: |==================================----------------| 67.7% Complete  => 0:00:11
    	progress: |==================================----------------| 68.3% Complete  => 0:00:11
    	progress: |==================================----------------| 68.9% Complete  => 0:00:11
    	progress: |===================================---------------| 69.6% Complete  => 0:00:11
    	progress: |===================================---------------| 70.2% Complete  => 0:00:11
    	progress: |===================================---------------| 70.8% Complete  => 0:00:11
    	progress: |====================================--------------| 71.4% Complete  => 0:00:11
    	progress: |====================================--------------| 72.0% Complete  => 0:00:11
    	progress: |====================================--------------| 72.7% Complete  => 0:00:11
    	progress: |=====================================-------------| 73.3% Complete  => 0:00:11
    	progress: |=====================================-------------| 73.9% Complete  => 0:00:11
    	progress: |=====================================-------------| 74.5% Complete  => 0:00:11
    	progress: |======================================------------| 75.2% Complete  => 0:00:11
    	progress: |======================================------------| 75.8% Complete  => 0:00:11
    	progress: |======================================------------| 76.4% Complete  => 0:00:11
    	progress: |=======================================-----------| 77.0% Complete  => 0:00:11
    	progress: |=======================================-----------| 77.6% Complete  => 0:00:11
    	progress: |=======================================-----------| 78.3% Complete  => 0:00:11
    	progress: |=======================================-----------| 78.9% Complete  => 0:00:11
    	progress: |========================================----------| 79.5% Complete  => 0:00:11
    	progress: |========================================----------| 80.1% Complete  => 0:00:11
    	progress: |========================================----------| 80.7% Complete  => 0:00:11
    	progress: |=========================================---------| 81.4% Complete  => 0:00:11
    	progress: |=========================================---------| 82.0% Complete  => 0:00:11
    	progress: |=========================================---------| 82.6% Complete  => 0:00:11
    	progress: |==========================================--------| 83.2% Complete  => 0:00:11
    	progress: |==========================================--------| 83.9% Complete  => 0:00:12
    	progress: |==========================================--------| 84.5% Complete  => 0:00:12
    	progress: |===========================================-------| 85.1% Complete  => 0:00:12
    	progress: |===========================================-------| 85.7% Complete  => 0:00:12
    	progress: |===========================================-------| 86.3% Complete  => 0:00:12
    	progress: |===========================================-------| 87.0% Complete  => 0:00:12
    	progress: |============================================------| 87.6% Complete  => 0:00:12
    	progress: |============================================------| 88.2% Complete  => 0:00:12
    	progress: |============================================------| 88.8% Complete  => 0:00:12
    	progress: |=============================================-----| 89.4% Complete  => 0:00:12
    	progress: |=============================================-----| 90.1% Complete  => 0:00:12
    	progress: |=============================================-----| 90.7% Complete  => 0:00:12
    	progress: |==============================================----| 91.3% Complete  => 0:00:12
    	progress: |==============================================----| 91.9% Complete  => 0:00:12
    	progress: |==============================================----| 92.5% Complete  => 0:00:12
    	progress: |===============================================---| 93.2% Complete  => 0:00:12
    	progress: |===============================================---| 93.8% Complete  => 0:00:12
    	progress: |===============================================---| 94.4% Complete  => 0:00:12
    	progress: |================================================--| 95.0% Complete  => 0:00:12
    	progress: |================================================--| 95.7% Complete  => 0:00:12
    	progress: |================================================--| 96.3% Complete  => 0:00:12
    	progress: |================================================--| 96.9% Complete  => 0:00:12
    	progress: |=================================================-| 97.5% Complete  => 0:00:12
    	progress: |=================================================-| 98.1% Complete  => 0:00:12
    	progress: |=================================================-| 98.8% Complete  => 0:00:12
    	progress: |==================================================| 99.4% Complete  => 0:00:12
    	progress: |==================================================| 100.0% Complete  => 0:00:12

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_spatial_transform.py 17 0:00:38.042002

### PASSED Test_Geometry_Transformer::test_to_map_geometry 0:00:01.755424

Started | 2025-06-06 14:44:01
Ended | 2025-06-06 14:44:03
Duration | 0:00:01.755424
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:44:01:   Reading Input Data
    2025/06/06 14:44:01:   Reading metadata for VNIR detector...
    2025/06/06 14:44:02:   Calculating solar irradiance...
    2025/06/06 14:44:02:   Reading metadata for SWIR detector...
    2025/06/06 14:44:02:   Calculating solar irradiance...
    2025/06/06 14:44:02:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:44:02:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:44:02:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Geometry_Transformer::test_to_sensor_geometry 0:00:01.402970

Started | 2025-06-06 14:44:03
Ended | 2025-06-06 14:44:04
Duration | 0:00:01.402970
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/06 14:44:03:   Reading Input Data
    2025/06/06 14:44:03:   Reading metadata for VNIR detector...
    2025/06/06 14:44:03:   Calculating solar irradiance...
    2025/06/06 14:44:03:   Reading metadata for SWIR detector...
    2025/06/06 14:44:04:   Calculating solar irradiance...
    2025/06/06 14:44:04:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:44:04:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:44:04:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2D 0:00:02.377425

Started | 2025-06-06 14:44:04
Ended | 2025-06-06 14:44:07
Duration | 0:00:02.377425
Markers |
Fixtures | request

#### Setup

##### Captured stdout setup

    2025/06/06 14:44:04:   Reading Input Data
    2025/06/06 14:44:04:   Reading metadata for VNIR detector...
    2025/06/06 14:44:05:   Calculating solar irradiance...
    2025/06/06 14:44:05:   Reading metadata for SWIR detector...
    2025/06/06 14:44:05:   Calculating solar irradiance...
    2025/06/06 14:44:05:   Reading image masks in VNIR sensor geometry.
    2025/06/06 14:44:06:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/06 14:44:06:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/06 14:44:06:   Computing VNIR geolayer...
    2025/06/06 14:44:06:   Computing SWIR geolayer...

##### Captured stderr setup

    2025/06/06 14:44:04:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log setup

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2band3DInput_2DGeolayer 0:00:00.404345

Started | 2025-06-06 14:44:07
Ended | 2025-06-06 14:44:07
Duration | 0:00:00.404345
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2band3DInput_3DGeolayer 0:00:00.440594

Started | 2025-06-06 14:44:07
Ended | 2025-06-06 14:44:07
Duration | 0:00:00.440594
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_VNIR_to_SWIR_2D 0:00:00.418537

Started | 2025-06-06 14:44:07
Ended | 2025-06-06 14:44:08
Duration | 0:00:00.418537
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_VNIR_to_SWIR_3D 0:00:23.774386

Started | 2025-06-06 14:44:08
Ended | 2025-06-06 14:44:32
Duration | 0:00:23.774386
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_geolayer 0:00:00.522883

Started | 2025-06-06 14:44:32
Ended | 2025-06-06 14:44:32
Duration | 0:00:00.522883
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_geolayer_average_elevation 0:00:00.451467

Started | 2025-06-06 14:44:32
Ended | 2025-06-06 14:44:33
Duration | 0:00:00.451467
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_normalized_image_coordinates 0:00:00.007017

Started | 2025-06-06 14:44:33
Ended | 2025-06-06 14:44:33
Duration | 0:00:00.007017
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_normalize_coordinates 0:00:00.002954

Started | 2025-06-06 14:44:33
Ended | 2025-06-06 14:44:33
Duration | 0:00:00.002954
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_transform_LonLatHeight_to_RowCol 0:00:00.002972

Started | 2025-06-06 14:44:33
Ended | 2025-06-06 14:44:33
Duration | 0:00:00.002972
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_average_elevation 0:00:01.988001

Started | 2025-06-06 14:44:33
Ended | 2025-06-06 14:44:35
Duration | 0:00:01.988001
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_faulty_coeff_set 0:00:00.536735

Test in case of a faulty/inaccurate coeff set the result really does not contain NaNs.

NOTE: NaNs should be filled automatically.

Started | 2025-06-06 14:44:35
Ended | 2025-06-06 14:44:35
Duration | 0:00:00.536735
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_multiple_coeff_sets_multiprocessing 0:00:02.118474

Started | 2025-06-06 14:44:35
Ended | 2025-06-06 14:44:37
Duration | 0:00:02.118474
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_multiple_coeff_sets_singleprocessing 0:00:01.400335

Started | 2025-06-06 14:44:37
Ended | 2025-06-06 14:44:39
Duration | 0:00:01.400335
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_one_unique_coeff_set 0:00:00.437482

Started | 2025-06-06 14:44:39
Ended | 2025-06-06 14:44:39
Duration | 0:00:00.437482
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_srf.py 1 0:00:00.006059

### PASSED Test_SRF::test_from_cwl_fwhm 0:00:00.006059

Started | 2025-06-06 14:44:39
Ended | 2025-06-06 14:44:39
Duration | 0:00:00.006059
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown